/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtChartAPI_H
#define _QtChartAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QtCharts__QAbstractBarSeries__LabelsPosition 0
#define sipName_QtCharts__QAbstractBarSeries__LabelsPosition &sipStrings_QtChart[0]
#define sipNameNr_QtCharts__QCategoryAxis__AxisLabelsPosition 45
#define sipName_QtCharts__QCategoryAxis__AxisLabelsPosition &sipStrings_QtChart[45]
#define sipNameNr_QtCharts__QLegendMarker__LegendMarkerType 89
#define sipName_QtCharts__QLegendMarker__LegendMarkerType &sipStrings_QtChart[89]
#define sipNameNr_QtCharts__QPolarChart__PolarOrientations 131
#define sipName_QtCharts__QPolarChart__PolarOrientations &sipStrings_QtChart[131]
#define sipNameNr_QtCharts__QPolarChart__PolarOrientation 172
#define sipName_QtCharts__QPolarChart__PolarOrientation &sipStrings_QtChart[172]
#define sipNameNr_QtCharts__QAbstractSeries__SeriesType 212
#define sipName_QtCharts__QAbstractSeries__SeriesType &sipStrings_QtChart[212]
#define sipNameNr_QtCharts__QHorizontalPercentBarSeries 250
#define sipName_QtCharts__QHorizontalPercentBarSeries &sipStrings_QtChart[250]
#define sipNameNr_QtCharts__QHorizontalStackedBarSeries 288
#define sipName_QtCharts__QHorizontalStackedBarSeries &sipStrings_QtChart[288]
#define sipNameNr_QtCharts__QScatterSeries__MarkerShape 326
#define sipName_QtCharts__QScatterSeries__MarkerShape &sipStrings_QtChart[326]
#define sipNameNr_QtCharts__QAbstractAxis__AxisTypes 364
#define sipName_QtCharts__QAbstractAxis__AxisTypes &sipStrings_QtChart[364]
#define sipNameNr_QtCharts__QCandlestickLegendMarker 399
#define sipName_QtCharts__QCandlestickLegendMarker &sipStrings_QtChart[399]
#define sipNameNr_QtCharts__QChart__AnimationOptions 434
#define sipName_QtCharts__QChart__AnimationOptions &sipStrings_QtChart[434]
#define sipNameNr_QtCharts__QHCandlestickModelMapper 469
#define sipName_QtCharts__QHCandlestickModelMapper &sipStrings_QtChart[469]
#define sipNameNr_QtCharts__QPieSlice__LabelPosition 504
#define sipName_QtCharts__QPieSlice__LabelPosition &sipStrings_QtChart[504]
#define sipNameNr_QtCharts__QVCandlestickModelMapper 539
#define sipName_QtCharts__QVCandlestickModelMapper &sipStrings_QtChart[539]
#define sipNameNr_574 574
#define sipName_574 &sipStrings_QtChart[574]
#define sipNameNr_608 608
#define sipName_608 &sipStrings_QtChart[608]
#define sipNameNr_QtCharts__QAbstractAxis__AxisType 642
#define sipName_QtCharts__QAbstractAxis__AxisType &sipStrings_QtChart[642]
#define sipNameNr_QtCharts__QBoxSet__ValuePositions 676
#define sipName_QtCharts__QBoxSet__ValuePositions &sipStrings_QtChart[676]
#define sipNameNr_QtCharts__QCandlestickModelMapper 710
#define sipName_QtCharts__QCandlestickModelMapper &sipStrings_QtChart[710]
#define sipNameNr_QtCharts__QChart__AnimationOption 744
#define sipName_QtCharts__QChart__AnimationOption &sipStrings_QtChart[744]
#define sipNameNr_QtCharts__QChartView__RubberBands 778
#define sipName_QtCharts__QChartView__RubberBands &sipStrings_QtChart[778]
#define sipNameNr_QtCharts__QChartView__RubberBand 812
#define sipName_QtCharts__QChartView__RubberBand &sipStrings_QtChart[812]
#define sipNameNr_845 845
#define sipName_845 &sipStrings_QtChart[845]
#define sipNameNr_877 877
#define sipName_877 &sipStrings_QtChart[877]
#define sipNameNr_QtCharts__QBoxPlotLegendMarker 909
#define sipName_QtCharts__QBoxPlotLegendMarker &sipStrings_QtChart[909]
#define sipNameNr_QtCharts__QHBoxPlotModelMapper 940
#define sipName_QtCharts__QHBoxPlotModelMapper &sipStrings_QtChart[940]
#define sipNameNr_QtCharts__QHorizontalBarSeries 971
#define sipName_QtCharts__QHorizontalBarSeries &sipStrings_QtChart[971]
#define sipNameNr_QtCharts__QLegend__MarkerShape 1002
#define sipName_QtCharts__QLegend__MarkerShape &sipStrings_QtChart[1002]
#define sipNameNr_QtCharts__QVBoxPlotModelMapper 1033
#define sipName_QtCharts__QVBoxPlotModelMapper &sipStrings_QtChart[1033]
#define sipNameNr_QtCharts__QValueAxis__TickType 1064
#define sipName_QtCharts__QValueAxis__TickType &sipStrings_QtChart[1064]
#define sipNameNr_SeriesTypeHorizontalPercentBar 1095
#define sipName_SeriesTypeHorizontalPercentBar &sipStrings_QtChart[1095]
#define sipNameNr_SeriesTypeHorizontalStackedBar 1126
#define sipName_SeriesTypeHorizontalStackedBar &sipStrings_QtChart[1126]
#define sipNameNr_QtCharts__QAbstractBarSeries 1157
#define sipName_QtCharts__QAbstractBarSeries &sipStrings_QtChart[1157]
#define sipNameNr_QtCharts__QCandlestickSeries 1186
#define sipName_QtCharts__QCandlestickSeries &sipStrings_QtChart[1186]
#define sipNameNr_QtCharts__QChart__ChartTheme 1215
#define sipName_QtCharts__QChart__ChartTheme &sipStrings_QtChart[1215]
#define sipNameNr_bodyOutlineVisibilityChanged 1244
#define sipName_bodyOutlineVisibilityChanged &sipStrings_QtChart[1244]
#define sipNameNr_pointLabelsVisibilityChanged 1273
#define sipName_pointLabelsVisibilityChanged &sipStrings_QtChart[1273]
#define sipNameNr_setPlotAreaBackgroundVisible 1302
#define sipName_setPlotAreaBackgroundVisible &sipStrings_QtChart[1302]
#define sipNameNr_LegendMarkerTypeCandlestick 1331
#define sipName_LegendMarkerTypeCandlestick &sipStrings_QtChart[1331]
#define sipNameNr_QHorizontalPercentBarSeries 260
#define sipName_QHorizontalPercentBarSeries &sipStrings_QtChart[260]
#define sipNameNr_QHorizontalStackedBarSeries 298
#define sipName_QHorizontalStackedBarSeries &sipStrings_QtChart[298]
#define sipNameNr_1359 1359
#define sipName_1359 &sipStrings_QtChart[1359]
#define sipNameNr_QtCharts__QAreaLegendMarker 1387
#define sipName_QtCharts__QAreaLegendMarker &sipStrings_QtChart[1387]
#define sipNameNr_QtCharts__QChart__ChartType 1415
#define sipName_QtCharts__QChart__ChartType &sipStrings_QtChart[1415]
#define sipNameNr_QtCharts__QPercentBarSeries 1443
#define sipName_QtCharts__QPercentBarSeries &sipStrings_QtChart[1443]
#define sipNameNr_QtCharts__QStackedBarSeries 1471
#define sipName_QtCharts__QStackedBarSeries &sipStrings_QtChart[1471]
#define sipNameNr_boxOutlineVisibilityChanged 1499
#define sipName_boxOutlineVisibilityChanged &sipStrings_QtChart[1499]
#define sipNameNr_isPlotAreaBackgroundVisible 1527
#define sipName_isPlotAreaBackgroundVisible &sipStrings_QtChart[1527]
#define sipNameNr_QtCharts__QBarCategoryAxis 1555
#define sipName_QtCharts__QBarCategoryAxis &sipStrings_QtChart[1555]
#define sipNameNr_QtCharts__QBarLegendMarker 1582
#define sipName_QtCharts__QBarLegendMarker &sipStrings_QtChart[1582]
#define sipNameNr_QtCharts__QHBarModelMapper 1609
#define sipName_QtCharts__QHBarModelMapper &sipStrings_QtChart[1609]
#define sipNameNr_QtCharts__QHPieModelMapper 1636
#define sipName_QtCharts__QHPieModelMapper &sipStrings_QtChart[1636]
#define sipNameNr_QtCharts__QPieLegendMarker 1663
#define sipName_QtCharts__QPieLegendMarker &sipStrings_QtChart[1663]
#define sipNameNr_QtCharts__QVBarModelMapper 1690
#define sipName_QtCharts__QVBarModelMapper &sipStrings_QtChart[1690]
#define sipNameNr_QtCharts__QVPieModelMapper 1717
#define sipName_QtCharts__QVPieModelMapper &sipStrings_QtChart[1717]
#define sipNameNr_pointLabelsClippingChanged 1744
#define sipName_pointLabelsClippingChanged &sipStrings_QtChart[1744]
#define sipNameNr_setPlotAreaBackgroundBrush 1771
#define sipName_setPlotAreaBackgroundBrush &sipStrings_QtChart[1771]
#define sipNameNr_AxisLabelsPositionOnValue 1798
#define sipName_AxisLabelsPositionOnValue &sipStrings_QtChart[1798]
#define sipNameNr_1824 1824
#define sipName_1824 &sipStrings_QtChart[1824]
#define sipNameNr_1850 1850
#define sipName_1850 &sipStrings_QtChart[1850]
#define sipNameNr_QtCharts__QAbstractSeries 1876
#define sipName_QtCharts__QAbstractSeries &sipStrings_QtChart[1876]
#define sipNameNr_QtCharts__QCandlestickSet 1902
#define sipName_QtCharts__QCandlestickSet &sipStrings_QtChart[1902]
#define sipNameNr_QtCharts__QHXYModelMapper 1928
#define sipName_QtCharts__QHXYModelMapper &sipStrings_QtChart[1928]
#define sipNameNr_QtCharts__QVXYModelMapper 1954
#define sipName_QtCharts__QVXYModelMapper &sipStrings_QtChart[1954]
#define sipNameNr_QtCharts__QXYLegendMarker 1980
#define sipName_QtCharts__QXYLegendMarker &sipStrings_QtChart[1980]
#define sipNameNr_maximumColumnWidthChanged 2006
#define sipName_maximumColumnWidthChanged &sipStrings_QtChart[2006]
#define sipNameNr_minimumColumnWidthChanged 2032
#define sipName_minimumColumnWidthChanged &sipStrings_QtChart[2032]
#define sipNameNr_minorGridLineColorChanged 2058
#define sipName_minorGridLineColorChanged &sipStrings_QtChart[2058]
#define sipNameNr_AxisLabelsPositionCenter 2084
#define sipName_AxisLabelsPositionCenter &sipStrings_QtChart[2084]
#define sipNameNr_QCandlestickLegendMarker 409
#define sipName_QCandlestickLegendMarker &sipStrings_QtChart[409]
#define sipNameNr_QHCandlestickModelMapper 479
#define sipName_QHCandlestickModelMapper &sipStrings_QtChart[479]
#define sipNameNr_QVCandlestickModelMapper 549
#define sipName_QVCandlestickModelMapper &sipStrings_QtChart[549]
#define sipNameNr_QtCharts__QBoxPlotSeries 2109
#define sipName_QtCharts__QBoxPlotSeries &sipStrings_QtChart[2109]
#define sipNameNr_QtCharts__QScatterSeries 2134
#define sipName_QtCharts__QScatterSeries &sipStrings_QtChart[2134]
#define sipNameNr_backgroundVisibleChanged 2159
#define sipName_backgroundVisibleChanged &sipStrings_QtChart[2159]
#define sipNameNr_firstBarSetColumnChanged 2184
#define sipName_firstBarSetColumnChanged &sipStrings_QtChart[2184]
#define sipNameNr_firstBoxSetColumnChanged 2209
#define sipName_firstBoxSetColumnChanged &sipStrings_QtChart[2209]
#define sipNameNr_pointLabelsFormatChanged 2234
#define sipName_pointLabelsFormatChanged &sipStrings_QtChart[2234]
#define sipNameNr_setExplodeDistanceFactor 2259
#define sipName_setExplodeDistanceFactor &sipStrings_QtChart[2259]
#define sipNameNr_setPlotAreaBackgroundPen 2284
#define sipName_setPlotAreaBackgroundPen &sipStrings_QtChart[2284]
#define sipNameNr_shadesBorderColorChanged 2309
#define sipName_shadesBorderColorChanged &sipStrings_QtChart[2309]
#define sipNameNr_LegendMarkerTypeBoxPlot 2334
#define sipName_LegendMarkerTypeBoxPlot &sipStrings_QtChart[2334]
#define sipNameNr_PolarOrientationAngular 2358
#define sipName_PolarOrientationAngular &sipStrings_QtChart[2358]
#define sipNameNr_QCandlestickModelMapper 720
#define sipName_QCandlestickModelMapper &sipStrings_QtChart[720]
#define sipNameNr_QtCharts__QAbstractAxis 2382
#define sipName_QtCharts__QAbstractAxis &sipStrings_QtChart[2382]
#define sipNameNr_QtCharts__QCategoryAxis 2406
#define sipName_QtCharts__QCategoryAxis &sipStrings_QtChart[2406]
#define sipNameNr_QtCharts__QDateTimeAxis 2430
#define sipName_QtCharts__QDateTimeAxis &sipStrings_QtChart[2430]
#define sipNameNr_QtCharts__QLegendMarker 2454
#define sipName_QtCharts__QLegendMarker &sipStrings_QtChart[2454]
#define sipNameNr_QtCharts__QLogValueAxis 2478
#define sipName_QtCharts__QLogValueAxis &sipStrings_QtChart[2478]
#define sipNameNr_QtCharts__QSplineSeries 2502
#define sipName_QtCharts__QSplineSeries &sipStrings_QtChart[2502]
#define sipNameNr_SeriesTypeHorizontalBar 2526
#define sipName_SeriesTypeHorizontalBar &sipStrings_QtChart[2526]
#define sipNameNr_lastBarSetColumnChanged 2550
#define sipName_lastBarSetColumnChanged &sipStrings_QtChart[2550]
#define sipNameNr_lastBoxSetColumnChanged 2574
#define sipName_lastBoxSetColumnChanged &sipStrings_QtChart[2574]
#define sipNameNr_minorGridLinePenChanged 2598
#define sipName_minorGridLinePenChanged &sipStrings_QtChart[2598]
#define sipNameNr_minorGridVisibleChanged 2622
#define sipName_minorGridVisibleChanged &sipStrings_QtChart[2622]
#define sipNameNr_plotAreaBackgroundBrush 2646
#define sipName_plotAreaBackgroundBrush &sipStrings_QtChart[2646]
#define sipNameNr_pointLabelsColorChanged 2670
#define sipName_pointLabelsColorChanged &sipStrings_QtChart[2670]
#define sipNameNr_setAnimationEasingCurve 2694
#define sipName_setAnimationEasingCurve &sipStrings_QtChart[2694]
#define sipNameNr_setLabelArmLengthFactor 2718
#define sipName_setLabelArmLengthFactor &sipStrings_QtChart[2718]
#define sipNameNr_setMinorGridLineVisible 2742
#define sipName_setMinorGridLineVisible &sipStrings_QtChart[2742]
#define sipNameNr_ChartThemeBlueCerulean 2766
#define sipName_ChartThemeBlueCerulean &sipStrings_QtChart[2766]
#define sipNameNr_ChartThemeHighContrast 2789
#define sipName_ChartThemeHighContrast &sipStrings_QtChart[2789]
#define sipNameNr_PYQT_CHART_VERSION_STR 2812
#define sipName_PYQT_CHART_VERSION_STR &sipStrings_QtChart[2812]
#define sipNameNr_PolarOrientationRadial 2835
#define sipName_PolarOrientationRadial &sipStrings_QtChart[2835]
#define sipNameNr_candlestickSetsRemoved 2858
#define sipName_candlestickSetsRemoved &sipStrings_QtChart[2858]
#define sipNameNr_decreasingColorChanged 2881
#define sipName_decreasingColorChanged &sipStrings_QtChart[2881]
#define sipNameNr_increasingColorChanged 2904
#define sipName_increasingColorChanged &sipStrings_QtChart[2904]
#define sipNameNr_isMinorGridLineVisible 2927
#define sipName_isMinorGridLineVisible &sipStrings_QtChart[2927]
#define sipNameNr_labelsPrecisionChanged 2950
#define sipName_labelsPrecisionChanged &sipStrings_QtChart[2950]
#define sipNameNr_pointLabelsFontChanged 2973
#define sipName_pointLabelsFontChanged &sipStrings_QtChart[2973]
#define sipNameNr_setBackgroundRoundness 2996
#define sipName_setBackgroundRoundness &sipStrings_QtChart[2996]
#define sipNameNr_setPointLabelsClipping 3019
#define sipName_setPointLabelsClipping &sipStrings_QtChart[3019]
#define sipNameNr_timestampColumnChanged 3042
#define sipName_timestampColumnChanged &sipStrings_QtChart[3042]
#define sipNameNr_LabelInsideHorizontal 3065
#define sipName_LabelInsideHorizontal &sipStrings_QtChart[3065]
#define sipNameNr_LabelInsideTangential 3087
#define sipName_LabelInsideTangential &sipStrings_QtChart[3087]
#define sipNameNr_MarkerShapeFromSeries 3109
#define sipName_MarkerShapeFromSeries &sipStrings_QtChart[3109]
#define sipNameNr_QtCharts__QAreaSeries 3131
#define sipName_QtCharts__QAreaSeries &sipStrings_QtChart[3131]
#define sipNameNr_QtCharts__QLineSeries 3153
#define sipName_QtCharts__QLineSeries &sipStrings_QtChart[3153]
#define sipNameNr_QtCharts__QPolarChart 3175
#define sipName_QtCharts__QPolarChart &sipStrings_QtChart[3175]
#define sipNameNr_SeriesTypeCandlestick 3197
#define sipName_SeriesTypeCandlestick &sipStrings_QtChart[3197]
#define sipNameNr_capsVisibilityChanged 3219
#define sipName_capsVisibilityChanged &sipStrings_QtChart[3219]
#define sipNameNr_explodeDistanceFactor 3241
#define sipName_explodeDistanceFactor &sipStrings_QtChart[3241]
#define sipNameNr_firstBarSetRowChanged 3263
#define sipName_firstBarSetRowChanged &sipStrings_QtChart[3263]
#define sipNameNr_firstBoxSetRowChanged 3285
#define sipName_firstBoxSetRowChanged &sipStrings_QtChart[3285]
#define sipNameNr_firstSetColumnChanged 3307
#define sipName_firstSetColumnChanged &sipStrings_QtChart[3307]
#define sipNameNr_labelsEditableChanged 3329
#define sipName_labelsEditableChanged &sipStrings_QtChart[3329]
#define sipNameNr_labelsPositionChanged 3351
#define sipName_labelsPositionChanged &sipStrings_QtChart[3351]
#define sipNameNr_minorTickCountChanged 3373
#define sipName_minorTickCountChanged &sipStrings_QtChart[3373]
#define sipNameNr_mouseDoubleClickEvent 3395
#define sipName_mouseDoubleClickEvent &sipStrings_QtChart[3395]
#define sipNameNr_plotAreaBackgroundPen 3417
#define sipName_plotAreaBackgroundPen &sipStrings_QtChart[3417]
#define sipNameNr_reverseMarkersChanged 3439
#define sipName_reverseMarkersChanged &sipStrings_QtChart[3439]
#define sipNameNr_setBodyOutlineVisible 3461
#define sipName_setBodyOutlineVisible &sipStrings_QtChart[3461]
#define sipNameNr_setHorizontalPosition 3483
#define sipName_setHorizontalPosition &sipStrings_QtChart[3483]
#define sipNameNr_setMaximumColumnWidth 3505
#define sipName_setMaximumColumnWidth &sipStrings_QtChart[3505]
#define sipNameNr_setMinimumColumnWidth 3527
#define sipName_setMinimumColumnWidth &sipStrings_QtChart[3527]
#define sipNameNr_setMinorGridLineColor 3549
#define sipName_setMinorGridLineColor &sipStrings_QtChart[3549]
#define sipNameNr_setPointLabelsVisible 3571
#define sipName_setPointLabelsVisible &sipStrings_QtChart[3571]
#define sipNameNr_HorizontalRubberBand 3593
#define sipName_HorizontalRubberBand &sipStrings_QtChart[3593]
#define sipNameNr_LegendMarkerTypeArea 3614
#define sipName_LegendMarkerTypeArea &sipStrings_QtChart[3614]
#define sipNameNr_MarkerShapeRectangle 3635
#define sipName_MarkerShapeRectangle &sipStrings_QtChart[3635]
#define sipNameNr_QBoxPlotLegendMarker 919
#define sipName_QBoxPlotLegendMarker &sipStrings_QtChart[919]
#define sipNameNr_QHBoxPlotModelMapper 950
#define sipName_QHBoxPlotModelMapper &sipStrings_QtChart[950]
#define sipNameNr_QHorizontalBarSeries 981
#define sipName_QHorizontalBarSeries &sipStrings_QtChart[981]
#define sipNameNr_QVBoxPlotModelMapper 1043
#define sipName_QVBoxPlotModelMapper &sipStrings_QtChart[1043]
#define sipNameNr_QtCharts__QBarSeries 3656
#define sipName_QtCharts__QBarSeries &sipStrings_QtChart[3656]
#define sipNameNr_QtCharts__QChartView 3677
#define sipName_QtCharts__QChartView &sipStrings_QtChart[3677]
#define sipNameNr_QtCharts__QPieSeries 3698
#define sipName_QtCharts__QPieSeries &sipStrings_QtChart[3698]
#define sipNameNr_QtCharts__QValueAxis 3719
#define sipName_QtCharts__QValueAxis &sipStrings_QtChart[3719]
#define sipNameNr_SeriesTypePercentBar 3740
#define sipName_SeriesTypePercentBar &sipStrings_QtChart[3740]
#define sipNameNr_SeriesTypeStackedBar 3761
#define sipName_SeriesTypeStackedBar &sipStrings_QtChart[3761]
#define sipNameNr_animationEasingCurve 3782
#define sipName_animationEasingCurve &sipStrings_QtChart[3782]
#define sipNameNr_axisPolarOrientation 3803
#define sipName_axisPolarOrientation &sipStrings_QtChart[3803]
#define sipNameNr_candlestickSetsAdded 3824
#define sipName_candlestickSetsAdded &sipStrings_QtChart[3824]
#define sipNameNr_gridLineColorChanged 3845
#define sipName_gridLineColorChanged &sipStrings_QtChart[3845]
#define sipNameNr_labelArmLengthFactor 3866
#define sipName_labelArmLengthFactor &sipStrings_QtChart[3866]
#define sipNameNr_labelsVisibleChanged 3887
#define sipName_labelsVisibleChanged &sipStrings_QtChart[3887]
#define sipNameNr_lastBarSetRowChanged 3908
#define sipName_lastBarSetRowChanged &sipStrings_QtChart[3908]
#define sipNameNr_lastBoxSetRowChanged 3929
#define sipName_lastBoxSetRowChanged &sipStrings_QtChart[3929]
#define sipNameNr_lastSetColumnChanged 3950
#define sipName_lastSetColumnChanged &sipStrings_QtChart[3950]
#define sipNameNr_setAnimationDuration 3971
#define sipName_setAnimationDuration &sipStrings_QtChart[3971]
#define sipNameNr_setBackgroundVisible 3992
#define sipName_setBackgroundVisible &sipStrings_QtChart[3992]
#define sipNameNr_setBoxOutlineVisible 4013
#define sipName_setBoxOutlineVisible &sipStrings_QtChart[4013]
#define sipNameNr_setDropShadowEnabled 4034
#define sipName_setDropShadowEnabled &sipStrings_QtChart[4034]
#define sipNameNr_setFirstBarSetColumn 4055
#define sipName_setFirstBarSetColumn &sipStrings_QtChart[4055]
#define sipNameNr_setFirstBoxSetColumn 4076
#define sipName_setFirstBoxSetColumn &sipStrings_QtChart[4076]
#define sipNameNr_setPointLabelsFormat 4097
#define sipName_setPointLabelsFormat &sipStrings_QtChart[4097]
#define sipNameNr_setShadesBorderColor 4118
#define sipName_setShadesBorderColor &sipStrings_QtChart[4118]
#define sipNameNr_shadesVisibleChanged 4139
#define sipName_shadesVisibleChanged &sipStrings_QtChart[4139]
#define sipNameNr_windowFrameSectionAt 4160
#define sipName_windowFrameSectionAt &sipStrings_QtChart[4160]
#define sipNameNr_AxisTypeBarCategory 4181
#define sipName_AxisTypeBarCategory &sipStrings_QtChart[4181]
#define sipNameNr_ChartThemeBrownSand 4201
#define sipName_ChartThemeBrownSand &sipStrings_QtChart[4201]
#define sipNameNr_LegendMarkerTypeBar 4221
#define sipName_LegendMarkerTypeBar &sipStrings_QtChart[4221]
#define sipNameNr_LegendMarkerTypePie 4241
#define sipName_LegendMarkerTypePie &sipStrings_QtChart[4241]
#define sipNameNr_QtCharts__QPieSlice 4261
#define sipName_QtCharts__QPieSlice &sipStrings_QtChart[4261]
#define sipNameNr_QtCharts__QXYSeries 4281
#define sipName_QtCharts__QXYSeries &sipStrings_QtChart[4281]
#define sipNameNr_RectangleRubberBand 4301
#define sipName_RectangleRubberBand &sipStrings_QtChart[4301]
#define sipNameNr_backgroundRoundness 4321
#define sipName_backgroundRoundness &sipStrings_QtChart[4321]
#define sipNameNr_isBackgroundVisible 4341
#define sipName_isBackgroundVisible &sipStrings_QtChart[4341]
#define sipNameNr_isDropShadowEnabled 4361
#define sipName_isDropShadowEnabled &sipStrings_QtChart[4361]
#define sipNameNr_labelVisibleChanged 4381
#define sipName_labelVisibleChanged &sipStrings_QtChart[4381]
#define sipNameNr_labelsColumnChanged 4401
#define sipName_labelsColumnChanged &sipStrings_QtChart[4401]
#define sipNameNr_labelsFormatChanged 4421
#define sipName_labelsFormatChanged &sipStrings_QtChart[4421]
#define sipNameNr_pointLabelsClipping 4441
#define sipName_pointLabelsClipping &sipStrings_QtChart[4441]
#define sipNameNr_setAnimationOptions 4461
#define sipName_setAnimationOptions &sipStrings_QtChart[4461]
#define sipNameNr_setLastBarSetColumn 4481
#define sipName_setLastBarSetColumn &sipStrings_QtChart[4481]
#define sipNameNr_setLastBoxSetColumn 4501
#define sipName_setLastBoxSetColumn &sipStrings_QtChart[4501]
#define sipNameNr_setMinorGridLinePen 4521
#define sipName_setMinorGridLinePen &sipStrings_QtChart[4521]
#define sipNameNr_setPointLabelsColor 4541
#define sipName_setPointLabelsColor &sipStrings_QtChart[4541]
#define sipNameNr_setVerticalPosition 4561
#define sipName_setVerticalPosition &sipStrings_QtChart[4561]
#define sipNameNr_showToolTipsChanged 4581
#define sipName_showToolTipsChanged &sipStrings_QtChart[4581]
#define sipNameNr_tickIntervalChanged 4601
#define sipName_tickIntervalChanged &sipStrings_QtChart[4601]
#define sipNameNr_timestampRowChanged 4621
#define sipName_timestampRowChanged &sipStrings_QtChart[4621]
#define sipNameNr_titleVisibleChanged 4641
#define sipName_titleVisibleChanged &sipStrings_QtChart[4641]
#define sipNameNr_ungrabKeyboardEvent 4661
#define sipName_ungrabKeyboardEvent &sipStrings_QtChart[4661]
#define sipNameNr_valuesColumnChanged 4681
#define sipName_valuesColumnChanged &sipStrings_QtChart[4681]
#define sipNameNr_AxisLabelsPosition 70
#define sipName_AxisLabelsPosition &sipStrings_QtChart[70]
#define sipNameNr_ChartTypeCartesian 4701
#define sipName_ChartTypeCartesian &sipStrings_QtChart[4701]
#define sipNameNr_ChartTypeUndefined 4720
#define sipName_ChartTypeUndefined &sipStrings_QtChart[4720]
#define sipNameNr_GridAxisAnimations 4739
#define sipName_GridAxisAnimations &sipStrings_QtChart[4739]
#define sipNameNr_LegendMarkerTypeXY 4758
#define sipName_LegendMarkerTypeXY &sipStrings_QtChart[4758]
#define sipNameNr_MarkerShapeDefault 4777
#define sipName_MarkerShapeDefault &sipStrings_QtChart[4777]
#define sipNameNr_PYQT_CHART_VERSION 4796
#define sipName_PYQT_CHART_VERSION &sipStrings_QtChart[4796]
#define sipNameNr_QAbstractBarSeries 1167
#define sipName_QAbstractBarSeries &sipStrings_QtChart[1167]
#define sipNameNr_QCandlestickSeries 1196
#define sipName_QCandlestickSeries &sipStrings_QtChart[1196]
#define sipNameNr_VerticalRubberBand 4815
#define sipName_VerticalRubberBand &sipStrings_QtChart[4815]
#define sipNameNr_bodyOutlineVisible 4834
#define sipName_bodyOutlineVisible &sipStrings_QtChart[4834]
#define sipNameNr_borderColorChanged 4853
#define sipName_borderColorChanged &sipStrings_QtChart[4853]
#define sipNameNr_borderWidthChanged 4872
#define sipName_borderWidthChanged &sipStrings_QtChart[4872]
#define sipNameNr_closeColumnChanged 4891
#define sipName_closeColumnChanged &sipStrings_QtChart[4891]
#define sipNameNr_columnCountChanged 4910
#define sipName_columnCountChanged &sipStrings_QtChart[4910]
#define sipNameNr_firstColumnChanged 4929
#define sipName_firstColumnChanged &sipStrings_QtChart[4929]
#define sipNameNr_firstSetRowChanged 4948
#define sipName_firstSetRowChanged &sipStrings_QtChart[4948]
#define sipNameNr_focusNextPrevChild 4967
#define sipName_focusNextPrevChild &sipStrings_QtChart[4967]
#define sipNameNr_getContentsMargins 4986
#define sipName_getContentsMargins &sipStrings_QtChart[4986]
#define sipNameNr_gridLinePenChanged 5005
#define sipName_gridLinePenChanged &sipStrings_QtChart[5005]
#define sipNameNr_gridVisibleChanged 5024
#define sipName_gridVisibleChanged &sipStrings_QtChart[5024]
#define sipNameNr_horizontalPosition 5043
#define sipName_horizontalPosition &sipStrings_QtChart[5043]
#define sipNameNr_labelFormatChanged 5062
#define sipName_labelFormatChanged &sipStrings_QtChart[5062]
#define sipNameNr_labelsAngleChanged 5081
#define sipName_labelsAngleChanged &sipStrings_QtChart[5081]
#define sipNameNr_labelsBrushChanged 5100
#define sipName_labelsBrushChanged &sipStrings_QtChart[5100]
#define sipNameNr_labelsColorChanged 5119
#define sipName_labelsColorChanged &sipStrings_QtChart[5119]
#define sipNameNr_lineVisibleChanged 5138
#define sipName_lineVisibleChanged &sipStrings_QtChart[5138]
#define sipNameNr_markerShapeChanged 5157
#define sipName_markerShapeChanged &sipStrings_QtChart[5157]
#define sipNameNr_maximumColumnWidth 5176
#define sipName_maximumColumnWidth &sipStrings_QtChart[5176]
#define sipNameNr_minimumColumnWidth 5195
#define sipName_minimumColumnWidth &sipStrings_QtChart[5195]
#define sipNameNr_minorGridLineColor 5214
#define sipName_minorGridLineColor &sipStrings_QtChart[5214]
#define sipNameNr_pointLabelsVisible 5233
#define sipName_pointLabelsVisible &sipStrings_QtChart[5233]
#define sipNameNr_setBackgroundBrush 5252
#define sipName_setBackgroundBrush &sipStrings_QtChart[5252]
#define sipNameNr_setDecreasingColor 5271
#define sipName_setDecreasingColor &sipStrings_QtChart[5271]
#define sipNameNr_setFirstSetSection 5290
#define sipName_setFirstSetSection &sipStrings_QtChart[5290]
#define sipNameNr_setGridLineVisible 5309
#define sipName_setGridLineVisible &sipStrings_QtChart[5309]
#define sipNameNr_setIncreasingColor 5328
#define sipName_setIncreasingColor &sipStrings_QtChart[5328]
#define sipNameNr_setLabelsPrecision 5347
#define sipName_setLabelsPrecision &sipStrings_QtChart[5347]
#define sipNameNr_setLocalizeNumbers 5366
#define sipName_setLocalizeNumbers &sipStrings_QtChart[5366]
#define sipNameNr_setPointLabelsFont 5385
#define sipName_setPointLabelsFont &sipStrings_QtChart[5385]
#define sipNameNr_setTimestampColumn 5404
#define sipName_setTimestampColumn &sipStrings_QtChart[5404]
#define sipNameNr_shadesBrushChanged 5423
#define sipName_shadesBrushChanged &sipStrings_QtChart[5423]
#define sipNameNr_shadesColorChanged 5442
#define sipName_shadesColorChanged &sipStrings_QtChart[5442]
#define sipNameNr_ChartThemeBlueIcy 5461
#define sipName_ChartThemeBlueIcy &sipStrings_QtChart[5461]
#define sipNameNr_ChartThemeBlueNcs 5479
#define sipName_ChartThemeBlueNcs &sipStrings_QtChart[5479]
#define sipNameNr_LabelInsideNormal 5497
#define sipName_LabelInsideNormal &sipStrings_QtChart[5497]
#define sipNameNr_MarkerShapeCircle 5515
#define sipName_MarkerShapeCircle &sipStrings_QtChart[5515]
#define sipNameNr_PolarOrientations 154
#define sipName_PolarOrientations &sipStrings_QtChart[154]
#define sipNameNr_QAreaLegendMarker 1397
#define sipName_QAreaLegendMarker &sipStrings_QtChart[1397]
#define sipNameNr_QPercentBarSeries 1453
#define sipName_QPercentBarSeries &sipStrings_QtChart[1453]
#define sipNameNr_QStackedBarSeries 1481
#define sipName_QStackedBarSeries &sipStrings_QtChart[1481]
#define sipNameNr_QtCharts__QBarSet 5533
#define sipName_QtCharts__QBarSet &sipStrings_QtChart[5533]
#define sipNameNr_QtCharts__QBoxSet 5551
#define sipName_QtCharts__QBoxSet &sipStrings_QtChart[5551]
#define sipNameNr_QtCharts__QLegend 5569
#define sipName_QtCharts__QLegend &sipStrings_QtChart[5569]
#define sipNameNr_SeriesTypeBoxPlot 5587
#define sipName_SeriesTypeBoxPlot &sipStrings_QtChart[5587]
#define sipNameNr_SeriesTypeScatter 5605
#define sipName_SeriesTypeScatter &sipStrings_QtChart[5605]
#define sipNameNr_animationDuration 5623
#define sipName_animationDuration &sipStrings_QtChart[5623]
#define sipNameNr_boxOutlineVisible 5641
#define sipName_boxOutlineVisible &sipStrings_QtChart[5641]
#define sipNameNr_categoriesChanged 5659
#define sipName_categoriesChanged &sipStrings_QtChart[5659]
#define sipNameNr_createDefaultAxes 5677
#define sipName_createDefaultAxes &sipStrings_QtChart[5677]
#define sipNameNr_firstBarSetColumn 5695
#define sipName_firstBarSetColumn &sipStrings_QtChart[5695]
#define sipNameNr_firstBoxSetColumn 5713
#define sipName_firstBoxSetColumn &sipStrings_QtChart[5713]
#define sipNameNr_grabKeyboardEvent 4663
#define sipName_grabKeyboardEvent &sipStrings_QtChart[4663]
#define sipNameNr_hasHeightForWidth 5731
#define sipName_hasHeightForWidth &sipStrings_QtChart[5731]
#define sipNameNr_highColumnChanged 5749
#define sipName_highColumnChanged &sipStrings_QtChart[5749]
#define sipNameNr_isAttachedToChart 5767
#define sipName_isAttachedToChart &sipStrings_QtChart[5767]
#define sipNameNr_isGridLineVisible 5785
#define sipName_isGridLineVisible &sipStrings_QtChart[5785]
#define sipNameNr_labelBrushChanged 5803
#define sipName_labelBrushChanged &sipStrings_QtChart[5803]
#define sipNameNr_labelColorChanged 5821
#define sipName_labelColorChanged &sipStrings_QtChart[5821]
#define sipNameNr_labelsFontChanged 5839
#define sipName_labelsFontChanged &sipStrings_QtChart[5839]
#define sipNameNr_lastSetRowChanged 5857
#define sipName_lastSetRowChanged &sipStrings_QtChart[5857]
#define sipNameNr_markerSizeChanged 5875
#define sipName_markerSizeChanged &sipStrings_QtChart[5875]
#define sipNameNr_mouseReleaseEvent 5893
#define sipName_mouseReleaseEvent &sipStrings_QtChart[5893]
#define sipNameNr_openColumnChanged 5911
#define sipName_openColumnChanged &sipStrings_QtChart[5911]
#define sipNameNr_percentageChanged 5929
#define sipName_percentageChanged &sipStrings_QtChart[5929]
#define sipNameNr_pointLabelsFormat 5947
#define sipName_pointLabelsFormat &sipStrings_QtChart[5947]
#define sipNameNr_setFirstBarSetRow 5965
#define sipName_setFirstBarSetRow &sipStrings_QtChart[5965]
#define sipNameNr_setFirstBoxSetRow 5983
#define sipName_setFirstBoxSetRow &sipStrings_QtChart[5983]
#define sipNameNr_setFirstSetColumn 6001
#define sipName_setFirstSetColumn &sipStrings_QtChart[6001]
#define sipNameNr_setLabelsEditable 6019
#define sipName_setLabelsEditable &sipStrings_QtChart[6019]
#define sipNameNr_setLabelsPosition 6037
#define sipName_setLabelsPosition &sipStrings_QtChart[6037]
#define sipNameNr_setLastSetSection 6055
#define sipName_setLastSetSection &sipStrings_QtChart[6055]
#define sipNameNr_setMinorTickCount 6073
#define sipName_setMinorTickCount &sipStrings_QtChart[6073]
#define sipNameNr_setReverseMarkers 6091
#define sipName_setReverseMarkers &sipStrings_QtChart[6091]
#define sipNameNr_shadesBorderColor 6109
#define sipName_shadesBorderColor &sipStrings_QtChart[6109]
#define sipNameNr_sip_simplewrapper 6127
#define sipName_sip_simplewrapper &sipStrings_QtChart[6127]
#define sipNameNr_startAngleChanged 6145
#define sipName_startAngleChanged &sipStrings_QtChart[6145]
#define sipNameNr_tickAnchorChanged 6163
#define sipName_tickAnchorChanged &sipStrings_QtChart[6163]
#define sipNameNr_titleBrushChanged 6181
#define sipName_titleBrushChanged &sipStrings_QtChart[6181]
#define sipNameNr_AnimationOptions 452
#define sipName_AnimationOptions &sipStrings_QtChart[452]
#define sipNameNr_AxisTypeCategory 6199
#define sipName_AxisTypeCategory &sipStrings_QtChart[6199]
#define sipNameNr_AxisTypeDateTime 6216
#define sipName_AxisTypeDateTime &sipStrings_QtChart[6216]
#define sipNameNr_AxisTypeLogValue 6233
#define sipName_AxisTypeLogValue &sipStrings_QtChart[6233]
#define sipNameNr_LabelsInsideBase 6250
#define sipName_LabelsInsideBase &sipStrings_QtChart[6250]
#define sipNameNr_LabelsOutsideEnd 6267
#define sipName_LabelsOutsideEnd &sipStrings_QtChart[6267]
#define sipNameNr_LegendMarkerType 114
#define sipName_LegendMarkerType &sipStrings_QtChart[114]
#define sipNameNr_PolarOrientation 195
#define sipName_PolarOrientation &sipStrings_QtChart[195]
#define sipNameNr_QBarCategoryAxis 1565
#define sipName_QBarCategoryAxis &sipStrings_QtChart[1565]
#define sipNameNr_QBarLegendMarker 1592
#define sipName_QBarLegendMarker &sipStrings_QtChart[1592]
#define sipNameNr_QHBarModelMapper 1619
#define sipName_QHBarModelMapper &sipStrings_QtChart[1619]
#define sipNameNr_QHPieModelMapper 1646
#define sipName_QHPieModelMapper &sipStrings_QtChart[1646]
#define sipNameNr_QPieLegendMarker 1673
#define sipName_QPieLegendMarker &sipStrings_QtChart[1673]
#define sipNameNr_QVBarModelMapper 1700
#define sipName_QVBarModelMapper &sipStrings_QtChart[1700]
#define sipNameNr_QVPieModelMapper 1727
#define sipName_QVPieModelMapper &sipStrings_QtChart[1727]
#define sipNameNr_QtCharts__QChart 6284
#define sipName_QtCharts__QChart &sipStrings_QtChart[6284]
#define sipNameNr_SeriesAnimations 6301
#define sipName_SeriesAnimations &sipStrings_QtChart[6301]
#define sipNameNr_SeriesTypeSpline 6318
#define sipName_SeriesTypeSpline &sipStrings_QtChart[6318]
#define sipNameNr_angleSpanChanged 6335
#define sipName_angleSpanChanged &sipStrings_QtChart[6335]
#define sipNameNr_animationOptions 6352
#define sipName_animationOptions &sipStrings_QtChart[6352]
#define sipNameNr_applyNiceNumbers 6369
#define sipName_applyNiceNumbers &sipStrings_QtChart[6369]
#define sipNameNr_bodyWidthChanged 6386
#define sipName_bodyWidthChanged &sipStrings_QtChart[6386]
#define sipNameNr_capsWidthChanged 6403
#define sipName_capsWidthChanged &sipStrings_QtChart[6403]
#define sipNameNr_categoriesLabels 6420
#define sipName_categoriesLabels &sipStrings_QtChart[6420]
#define sipNameNr_collidesWithItem 6437
#define sipName_collidesWithItem &sipStrings_QtChart[6437]
#define sipNameNr_collidesWithPath 6454
#define sipName_collidesWithPath &sipStrings_QtChart[6454]
#define sipNameNr_contextMenuEvent 6471
#define sipName_contextMenuEvent &sipStrings_QtChart[6471]
#define sipNameNr_disconnectNotify 6488
#define sipName_disconnectNotify &sipStrings_QtChart[6488]
#define sipNameNr_inputMethodEvent 6505
#define sipName_inputMethodEvent &sipStrings_QtChart[6505]
#define sipNameNr_inputMethodQuery 6522
#define sipName_inputMethodQuery &sipStrings_QtChart[6522]
#define sipNameNr_labelFontChanged 6539
#define sipName_labelFontChanged &sipStrings_QtChart[6539]
#define sipNameNr_labelsRowChanged 6556
#define sipName_labelsRowChanged &sipStrings_QtChart[6556]
#define sipNameNr_lastBarSetColumn 6573
#define sipName_lastBarSetColumn &sipStrings_QtChart[6573]
#define sipNameNr_lastBoxSetColumn 6590
#define sipName_lastBoxSetColumn &sipStrings_QtChart[6590]
#define sipNameNr_lowColumnChanged 6607
#define sipName_lowColumnChanged &sipStrings_QtChart[6607]
#define sipNameNr_minorGridLinePen 6624
#define sipName_minorGridLinePen &sipStrings_QtChart[6624]
#define sipNameNr_paintWindowFrame 6641
#define sipName_paintWindowFrame &sipStrings_QtChart[6641]
#define sipNameNr_pointLabelsColor 6658
#define sipName_pointLabelsColor &sipStrings_QtChart[6658]
#define sipNameNr_polarOrientation 6675
#define sipName_polarOrientation &sipStrings_QtChart[6675]
#define sipNameNr_sceneEventFilter 6692
#define sipName_sceneEventFilter &sipStrings_QtChart[6692]
#define sipNameNr_scrollContentsBy 6709
#define sipName_scrollContentsBy &sipStrings_QtChart[6709]
#define sipNameNr_setBackgroundPen 6726
#define sipName_setBackgroundPen &sipStrings_QtChart[6726]
#define sipNameNr_setGridLineColor 6743
#define sipName_setGridLineColor &sipStrings_QtChart[6743]
#define sipNameNr_setLabelPosition 6760
#define sipName_setLabelPosition &sipStrings_QtChart[6760]
#define sipNameNr_setLabelsVisible 6777
#define sipName_setLabelsVisible &sipStrings_QtChart[6777]
#define sipNameNr_setLastBarSetRow 6794
#define sipName_setLastBarSetRow &sipStrings_QtChart[6794]
#define sipNameNr_setLastBoxSetRow 6811
#define sipName_setLastBoxSetRow &sipStrings_QtChart[6811]
#define sipNameNr_setLastSetColumn 6828
#define sipName_setLastSetColumn &sipStrings_QtChart[6828]
#define sipNameNr_setPieStartAngle 6845
#define sipName_setPieStartAngle &sipStrings_QtChart[6845]
#define sipNameNr_setPointsVisible 6862
#define sipName_setPointsVisible &sipStrings_QtChart[6862]
#define sipNameNr_setShadesVisible 6879
#define sipName_setShadesVisible &sipStrings_QtChart[6879]
#define sipNameNr_shadesPenChanged 6896
#define sipName_shadesPenChanged &sipStrings_QtChart[6896]
#define sipNameNr_tickCountChanged 6913
#define sipName_tickCountChanged &sipStrings_QtChart[6913]
#define sipNameNr_timestampChanged 6930
#define sipName_timestampChanged &sipStrings_QtChart[6930]
#define sipNameNr_titleFontChanged 6947
#define sipName_titleFontChanged &sipStrings_QtChart[6947]
#define sipNameNr_titleTextChanged 6964
#define sipName_titleTextChanged &sipStrings_QtChart[6964]
#define sipNameNr_ungrabMouseEvent 6981
#define sipName_ungrabMouseEvent &sipStrings_QtChart[6981]
#define sipNameNr_useOpenGLChanged 6998
#define sipName_useOpenGLChanged &sipStrings_QtChart[6998]
#define sipNameNr_valuesRowChanged 7015
#define sipName_valuesRowChanged &sipStrings_QtChart[7015]
#define sipNameNr_verticalPosition 7032
#define sipName_verticalPosition &sipStrings_QtChart[7032]
#define sipNameNr_viewportSizeHint 7049
#define sipName_viewportSizeHint &sipStrings_QtChart[7049]
#define sipNameNr_windowFrameEvent 7066
#define sipName_windowFrameEvent &sipStrings_QtChart[7066]
#define sipNameNr_AnimationOption 762
#define sipName_AnimationOption &sipStrings_QtChart[762]
#define sipNameNr_ChartThemeLight 7083
#define sipName_ChartThemeLight &sipStrings_QtChart[7083]
#define sipNameNr_LabelsInsideEnd 7099
#define sipName_LabelsInsideEnd &sipStrings_QtChart[7099]
#define sipNameNr_QAbstractSeries 1886
#define sipName_QAbstractSeries &sipStrings_QtChart[1886]
#define sipNameNr_QCandlestickSet 1912
#define sipName_QCandlestickSet &sipStrings_QtChart[1912]
#define sipNameNr_QHXYModelMapper 1938
#define sipName_QHXYModelMapper &sipStrings_QtChart[1938]
#define sipNameNr_QVXYModelMapper 1964
#define sipName_QVXYModelMapper &sipStrings_QtChart[1964]
#define sipNameNr_QXYLegendMarker 1990
#define sipName_QXYLegendMarker &sipStrings_QtChart[1990]
#define sipNameNr_backgroundBrush 7115
#define sipName_backgroundBrush &sipStrings_QtChart[7115]
#define sipNameNr_boxWidthChanged 7131
#define sipName_boxWidthChanged &sipStrings_QtChart[7131]
#define sipNameNr_closeRowChanged 7147
#define sipName_closeRowChanged &sipStrings_QtChart[7147]
#define sipNameNr_decreasingColor 7163
#define sipName_decreasingColor &sipStrings_QtChart[7163]
#define sipNameNr_detachFromChart 7179
#define sipName_detachFromChart &sipStrings_QtChart[7179]
#define sipNameNr_firstRowChanged 7195
#define sipName_firstRowChanged &sipStrings_QtChart[7195]
#define sipNameNr_firstSetSection 7211
#define sipName_firstSetSection &sipStrings_QtChart[7211]
#define sipNameNr_hoverEnterEvent 7227
#define sipName_hoverEnterEvent &sipStrings_QtChart[7227]
#define sipNameNr_hoverLeaveEvent 7243
#define sipName_hoverLeaveEvent &sipStrings_QtChart[7243]
#define sipNameNr_increasingColor 7259
#define sipName_increasingColor &sipStrings_QtChart[7259]
#define sipNameNr_initStyleOption 7275
#define sipName_initStyleOption &sipStrings_QtChart[7275]
#define sipNameNr_isLabelsVisible 7291
#define sipName_isLabelsVisible &sipStrings_QtChart[7291]
#define sipNameNr_keyReleaseEvent 7307
#define sipName_keyReleaseEvent &sipStrings_QtChart[7307]
#define sipNameNr_labelsPrecision 7323
#define sipName_labelsPrecision &sipStrings_QtChart[7323]
#define sipNameNr_localizeNumbers 7339
#define sipName_localizeNumbers &sipStrings_QtChart[7339]
#define sipNameNr_minimumSizeHint 7355
#define sipName_minimumSizeHint &sipStrings_QtChart[7355]
#define sipNameNr_mousePressEvent 7371
#define sipName_mousePressEvent &sipStrings_QtChart[7371]
#define sipNameNr_plotAreaChanged 7387
#define sipName_plotAreaChanged &sipStrings_QtChart[7387]
#define sipNameNr_pointLabelsFont 7403
#define sipName_pointLabelsFont &sipStrings_QtChart[7403]
#define sipNameNr_removeAllSeries 7419
#define sipName_removeAllSeries &sipStrings_QtChart[7419]
#define sipNameNr_rowCountChanged 7435
#define sipName_rowCountChanged &sipStrings_QtChart[7435]
#define sipNameNr_setLabelVisible 7451
#define sipName_setLabelVisible &sipStrings_QtChart[7451]
#define sipNameNr_setLabelsColumn 7467
#define sipName_setLabelsColumn &sipStrings_QtChart[7467]
#define sipNameNr_setLabelsFormat 7483
#define sipName_setLabelsFormat &sipStrings_QtChart[7483]
#define sipNameNr_setLinePenColor 7499
#define sipName_setLinePenColor &sipStrings_QtChart[7499]
#define sipNameNr_setShowToolTips 7515
#define sipName_setShowToolTips &sipStrings_QtChart[7515]
#define sipNameNr_setTickInterval 7531
#define sipName_setTickInterval &sipStrings_QtChart[7531]
#define sipNameNr_setTimestampRow 7547
#define sipName_setTimestampRow &sipStrings_QtChart[7547]
#define sipNameNr_setTitleVisible 7563
#define sipName_setTitleVisible &sipStrings_QtChart[7563]
#define sipNameNr_setValuesColumn 7579
#define sipName_setValuesColumn &sipStrings_QtChart[7579]
#define sipNameNr_tickTypeChanged 7595
#define sipName_tickTypeChanged &sipStrings_QtChart[7595]
#define sipNameNr_timestampColumn 7611
#define sipName_timestampColumn &sipStrings_QtChart[7611]
#define sipNameNr_AxisTypeNoAxis 7627
#define sipName_AxisTypeNoAxis &sipStrings_QtChart[7627]
#define sipNameNr_ChartThemeDark 7642
#define sipName_ChartThemeDark &sipStrings_QtChart[7642]
#define sipNameNr_ChartTypePolar 7657
#define sipName_ChartTypePolar &sipStrings_QtChart[7657]
#define sipNameNr_LabelsPosition 30
#define sipName_LabelsPosition &sipStrings_QtChart[30]
#define sipNameNr_QBoxPlotSeries 2119
#define sipName_QBoxPlotSeries &sipStrings_QtChart[2119]
#define sipNameNr_7672 7672
#define sipName_7672 &sipStrings_QtChart[7672]
#define sipNameNr_QScatterSeries 2144
#define sipName_QScatterSeries &sipStrings_QtChart[2144]
#define sipNameNr_SeriesTypeArea 7687
#define sipName_SeriesTypeArea &sipStrings_QtChart[7687]
#define sipNameNr_SeriesTypeLine 7702
#define sipName_SeriesTypeLine &sipStrings_QtChart[7702]
#define sipNameNr_ValuePositions 695
#define sipName_ValuePositions &sipStrings_QtChart[695]
#define sipNameNr_barsetsRemoved 7717
#define sipName_barsetsRemoved &sipStrings_QtChart[7717]
#define sipNameNr_boxsetsRemoved 7732
#define sipName_boxsetsRemoved &sipStrings_QtChart[7732]
#define sipNameNr_dragEnterEvent 7747
#define sipName_dragEnterEvent &sipStrings_QtChart[7747]
#define sipNameNr_dragLeaveEvent 7762
#define sipName_dragLeaveEvent &sipStrings_QtChart[7762]
#define sipNameNr_drawBackground 7777
#define sipName_drawBackground &sipStrings_QtChart[7777]
#define sipNameNr_drawForeground 7792
#define sipName_drawForeground &sipStrings_QtChart[7792]
#define sipNameNr_firstBarSetRow 7807
#define sipName_firstBarSetRow &sipStrings_QtChart[7807]
#define sipNameNr_firstBoxSetRow 7822
#define sipName_firstBoxSetRow &sipStrings_QtChart[7822]
#define sipNameNr_firstSetColumn 7837
#define sipName_firstSetColumn &sipStrings_QtChart[7837]
#define sipNameNr_grabMouseEvent 6983
#define sipName_grabMouseEvent &sipStrings_QtChart[6983]
#define sipNameNr_heightForWidth 7852
#define sipName_heightForWidth &sipStrings_QtChart[7852]
#define sipNameNr_highRowChanged 7867
#define sipName_highRowChanged &sipStrings_QtChart[7867]
#define sipNameNr_hoverMoveEvent 7882
#define sipName_hoverMoveEvent &sipStrings_QtChart[7882]
#define sipNameNr_isLabelVisible 7897
#define sipName_isLabelVisible &sipStrings_QtChart[7897]
#define sipNameNr_isTitleVisible 7912
#define sipName_isTitleVisible &sipStrings_QtChart[7912]
#define sipNameNr_labelsEditable 7927
#define sipName_labelsEditable &sipStrings_QtChart[7927]
#define sipNameNr_labelsPosition 7942
#define sipName_labelsPosition &sipStrings_QtChart[7942]
#define sipNameNr_lastSetSection 7957
#define sipName_lastSetSection &sipStrings_QtChart[7957]
#define sipNameNr_linePenChanged 7972
#define sipName_linePenChanged &sipStrings_QtChart[7972]
#define sipNameNr_minorTickCount 7987
#define sipName_minorTickCount &sipStrings_QtChart[7987]
#define sipNameNr_mouseMoveEvent 8002
#define sipName_mouseMoveEvent &sipStrings_QtChart[8002]
#define sipNameNr_opacityChanged 8017
#define sipName_opacityChanged &sipStrings_QtChart[8017]
#define sipNameNr_openRowChanged 8032
#define sipName_openRowChanged &sipStrings_QtChart[8032]
#define sipNameNr_pointsReplaced 8047
#define sipName_pointsReplaced &sipStrings_QtChart[8047]
#define sipNameNr_reverseChanged 8062
#define sipName_reverseChanged &sipStrings_QtChart[8062]
#define sipNameNr_reverseMarkers 8077
#define sipName_reverseMarkers &sipStrings_QtChart[8077]
#define sipNameNr_seriesReplaced 8092
#define sipName_seriesReplaced &sipStrings_QtChart[8092]
#define sipNameNr_setBorderColor 8107
#define sipName_setBorderColor &sipStrings_QtChart[8107]
#define sipNameNr_setBorderWidth 8122
#define sipName_setBorderWidth &sipStrings_QtChart[8122]
#define sipNameNr_setCapsVisible 8137
#define sipName_setCapsVisible &sipStrings_QtChart[8137]
#define sipNameNr_setCloseColumn 8152
#define sipName_setCloseColumn &sipStrings_QtChart[8152]
#define sipNameNr_setColumnCount 8167
#define sipName_setColumnCount &sipStrings_QtChart[8167]
#define sipNameNr_setFirstColumn 8182
#define sipName_setFirstColumn &sipStrings_QtChart[8182]
#define sipNameNr_setFirstSetRow 8197
#define sipName_setFirstSetRow &sipStrings_QtChart[8197]
#define sipNameNr_setGridLinePen 8212
#define sipName_setGridLinePen &sipStrings_QtChart[8212]
#define sipNameNr_setLabelFormat 8227
#define sipName_setLabelFormat &sipStrings_QtChart[8227]
#define sipNameNr_setLabelsAngle 8242
#define sipName_setLabelsAngle &sipStrings_QtChart[8242]
#define sipNameNr_setLabelsBrush 8257
#define sipName_setLabelsBrush &sipStrings_QtChart[8257]
#define sipNameNr_setLabelsColor 8272
#define sipName_setLabelsColor &sipStrings_QtChart[8272]
#define sipNameNr_setLineVisible 8287
#define sipName_setLineVisible &sipStrings_QtChart[8287]
#define sipNameNr_setLowerSeries 8302
#define sipName_setLowerSeries &sipStrings_QtChart[8302]
#define sipNameNr_setMarkerShape 8317
#define sipName_setMarkerShape &sipStrings_QtChart[8317]
#define sipNameNr_setPieEndAngle 8332
#define sipName_setPieEndAngle &sipStrings_QtChart[8332]
#define sipNameNr_setShadesBrush 8347
#define sipName_setShadesBrush &sipStrings_QtChart[8347]
#define sipNameNr_setShadesColor 8362
#define sipName_setShadesColor &sipStrings_QtChart[8362]
#define sipNameNr_setUpperSeries 8377
#define sipName_setUpperSeries &sipStrings_QtChart[8377]
#define sipNameNr_updateGeometry 8392
#define sipName_updateGeometry &sipStrings_QtChart[8392]
#define sipNameNr_visibleChanged 8407
#define sipName_visibleChanged &sipStrings_QtChart[8407]
#define sipNameNr_xColumnChanged 8422
#define sipName_xColumnChanged &sipStrings_QtChart[8422]
#define sipNameNr_yColumnChanged 8437
#define sipName_yColumnChanged &sipStrings_QtChart[8437]
#define sipNameNr_AllAnimations 8452
#define sipName_AllAnimations &sipStrings_QtChart[8452]
#define sipNameNr_AxisTypeValue 8466
#define sipName_AxisTypeValue &sipStrings_QtChart[8466]
#define sipNameNr_LabelPosition 525
#define sipName_LabelPosition &sipStrings_QtChart[525]
#define sipNameNr_LowerQuartile 8480
#define sipName_LowerQuartile &sipStrings_QtChart[8480]
#define sipNameNr_PyQt5_QtChart 8494
#define sipName_PyQt5_QtChart &sipStrings_QtChart[8494]
#define sipNameNr_QAbstractAxis 2392
#define sipName_QAbstractAxis &sipStrings_QtChart[2392]
#define sipNameNr_QCategoryAxis 2416
#define sipName_QCategoryAxis &sipStrings_QtChart[2416]
#define sipNameNr_QDateTimeAxis 2440
#define sipName_QDateTimeAxis &sipStrings_QtChart[2440]
#define sipNameNr_QLegendMarker 2464
#define sipName_QLegendMarker &sipStrings_QtChart[2464]
#define sipNameNr_QLogValueAxis 2488
#define sipName_QLogValueAxis &sipStrings_QtChart[2488]
#define sipNameNr_QSplineSeries 2512
#define sipName_QSplineSeries &sipStrings_QtChart[2512]
#define sipNameNr_SeriesTypeBar 8508
#define sipName_SeriesTypeBar &sipStrings_QtChart[8508]
#define sipNameNr_SeriesTypePie 8522
#define sipName_SeriesTypePie &sipStrings_QtChart[8522]
#define sipNameNr_UpperQuartile 8536
#define sipName_UpperQuartile &sipStrings_QtChart[8536]
#define sipNameNr_attachToChart 8550
#define sipName_attachToChart &sipStrings_QtChart[8550]
#define sipNameNr_backgroundPen 8564
#define sipName_backgroundPen &sipStrings_QtChart[8564]
#define sipNameNr_categoryLabel 8578
#define sipName_categoryLabel &sipStrings_QtChart[8578]
#define sipNameNr_connectNotify 6491
#define sipName_connectNotify &sipStrings_QtChart[6491]
#define sipNameNr_doubleClicked 8592
#define sipName_doubleClicked &sipStrings_QtChart[8592]
#define sipNameNr_dragMoveEvent 8606
#define sipName_dragMoveEvent &sipStrings_QtChart[8606]
#define sipNameNr_focusOutEvent 8620
#define sipName_focusOutEvent &sipStrings_QtChart[8620]
#define sipNameNr_formatChanged 8634
#define sipName_formatChanged &sipStrings_QtChart[8634]
#define sipNameNr_gridLineColor 8648
#define sipName_gridLineColor &sipStrings_QtChart[8648]
#define sipNameNr_isLineVisible 8662
#define sipName_isLineVisible &sipStrings_QtChart[8662]
#define sipNameNr_keyPressEvent 8676
#define sipName_keyPressEvent &sipStrings_QtChart[8676]
#define sipNameNr_labelPosition 8690
#define sipName_labelPosition &sipStrings_QtChart[8690]
#define sipNameNr_labelsVisible 8704
#define sipName_labelsVisible &sipStrings_QtChart[8704]
#define sipNameNr_lastBarSetRow 8718
#define sipName_lastBarSetRow &sipStrings_QtChart[8718]
#define sipNameNr_lastBoxSetRow 8732
#define sipName_lastBoxSetRow &sipStrings_QtChart[8732]
#define sipNameNr_lastSetColumn 8746
#define sipName_lastSetColumn &sipStrings_QtChart[8746]
#define sipNameNr_lowRowChanged 8760
#define sipName_lowRowChanged &sipStrings_QtChart[8760]
#define sipNameNr_mapToPosition 8774
#define sipName_mapToPosition &sipStrings_QtChart[8774]
#define sipNameNr_modelReplaced 8788
#define sipName_modelReplaced &sipStrings_QtChart[8788]
#define sipNameNr_pieStartAngle 8802
#define sipName_pieStartAngle &sipStrings_QtChart[8802]
#define sipNameNr_pointReplaced 8816
#define sipName_pointReplaced &sipStrings_QtChart[8816]
#define sipNameNr_pointsRemoved 8830
#define sipName_pointsRemoved &sipStrings_QtChart[8830]
#define sipNameNr_pointsVisible 8844
#define sipName_pointsVisible &sipStrings_QtChart[8844]
#define sipNameNr_setCategories 8858
#define sipName_setCategories &sipStrings_QtChart[8858]
#define sipNameNr_setHighColumn 8872
#define sipName_setHighColumn &sipStrings_QtChart[8872]
#define sipNameNr_setLabelBrush 8886
#define sipName_setLabelBrush &sipStrings_QtChart[8886]
#define sipNameNr_setLabelColor 8900
#define sipName_setLabelColor &sipStrings_QtChart[8900]
#define sipNameNr_setLabelsFont 8914
#define sipName_setLabelsFont &sipStrings_QtChart[8914]
#define sipNameNr_setLastSetRow 8928
#define sipName_setLastSetRow &sipStrings_QtChart[8928]
#define sipNameNr_setMarkerSize 8942
#define sipName_setMarkerSize &sipStrings_QtChart[8942]
#define sipNameNr_setOpenColumn 8956
#define sipName_setOpenColumn &sipStrings_QtChart[8956]
#define sipNameNr_setRubberBand 8970
#define sipName_setRubberBand &sipStrings_QtChart[8970]
#define sipNameNr_setStartValue 8984
#define sipName_setStartValue &sipStrings_QtChart[8984]
#define sipNameNr_setTickAnchor 8998
#define sipName_setTickAnchor &sipStrings_QtChart[8998]
#define sipNameNr_setTitleBrush 9012
#define sipName_setTitleBrush &sipStrings_QtChart[9012]
#define sipNameNr_setupViewport 9026
#define sipName_setupViewport &sipStrings_QtChart[9026]
#define sipNameNr_shadesVisible 9040
#define sipName_shadesVisible &sipStrings_QtChart[9040]
#define sipNameNr_sharedPainter 9054
#define sipName_sharedPainter &sipStrings_QtChart[9054]
#define sipNameNr_valuesChanged 9068
#define sipName_valuesChanged &sipStrings_QtChart[9068]
#define sipNameNr_valuesRemoved 9082
#define sipName_valuesRemoved &sipStrings_QtChart[9082]
#define sipNameNr_viewportEvent 9096
#define sipName_viewportEvent &sipStrings_QtChart[9096]
#define sipNameNr_ChartThemeQt 9110
#define sipName_ChartThemeQt &sipStrings_QtChart[9110]
#define sipNameNr_LabelOutside 9123
#define sipName_LabelOutside &sipStrings_QtChart[9123]
#define sipNameNr_LabelsCenter 9136
#define sipName_LabelsCenter &sipStrings_QtChart[9136]
#define sipNameNr_LowerExtreme 9149
#define sipName_LowerExtreme &sipStrings_QtChart[9149]
#define sipNameNr_NoRubberBand 9162
#define sipName_NoRubberBand &sipStrings_QtChart[9162]
#define sipNameNr_TicksDynamic 9175
#define sipName_TicksDynamic &sipStrings_QtChart[9175]
#define sipNameNr_UpperExtreme 9188
#define sipName_UpperExtreme &sipStrings_QtChart[9188]
#define sipNameNr_attachedAxes 9201
#define sipName_attachedAxes &sipStrings_QtChart[9201]
#define sipNameNr_barsetsAdded 9214
#define sipName_barsetsAdded &sipStrings_QtChart[9214]
#define sipNameNr_boundingRect 9227
#define sipName_boundingRect &sipStrings_QtChart[9227]
#define sipNameNr_boxsetsAdded 9240
#define sipName_boxsetsAdded &sipStrings_QtChart[9240]
#define sipNameNr_brushChanged 9253
#define sipName_brushChanged &sipStrings_QtChart[9253]
#define sipNameNr_closeChanged 9266
#define sipName_closeChanged &sipStrings_QtChart[9266]
#define sipNameNr_colorChanged 9279
#define sipName_colorChanged &sipStrings_QtChart[9279]
#define sipNameNr_countChanged 9292
#define sipName_countChanged &sipStrings_QtChart[9292]
#define sipNameNr_focusInEvent 9305
#define sipName_focusInEvent &sipStrings_QtChart[9305]
#define sipNameNr_isObscuredBy 9318
#define sipName_isObscuredBy &sipStrings_QtChart[9318]
#define sipNameNr_labelChanged 9331
#define sipName_labelChanged &sipStrings_QtChart[9331]
#define sipNameNr_labelsColumn 9344
#define sipName_labelsColumn &sipStrings_QtChart[9344]
#define sipNameNr_labelsFormat 9357
#define sipName_labelsFormat &sipStrings_QtChart[9357]
#define sipNameNr_linePenColor 9370
#define sipName_linePenColor &sipStrings_QtChart[9370]
#define sipNameNr_pointRemoved 9383
#define sipName_pointRemoved &sipStrings_QtChart[9383]
#define sipNameNr_pointsVector 9396
#define sipName_pointsVector &sipStrings_QtChart[9396]
#define sipNameNr_rangeChanged 9409
#define sipName_rangeChanged &sipStrings_QtChart[9409]
#define sipNameNr_removePoints 9422
#define sipName_removePoints &sipStrings_QtChart[9422]
#define sipNameNr_removeSeries 9435
#define sipName_removeSeries &sipStrings_QtChart[9435]
#define sipNameNr_replaceLabel 9448
#define sipName_replaceLabel &sipStrings_QtChart[9448]
#define sipNameNr_setAlignment 9461
#define sipName_setAlignment &sipStrings_QtChart[9461]
#define sipNameNr_setBodyWidth 9474
#define sipName_setBodyWidth &sipStrings_QtChart[9474]
#define sipNameNr_setCapsWidth 9487
#define sipName_setCapsWidth &sipStrings_QtChart[9487]
#define sipNameNr_setLabelFont 9500
#define sipName_setLabelFont &sipStrings_QtChart[9500]
#define sipNameNr_setLabelsRow 9513
#define sipName_setLabelsRow &sipStrings_QtChart[9513]
#define sipNameNr_setLowColumn 9526
#define sipName_setLowColumn &sipStrings_QtChart[9526]
#define sipNameNr_setShadesPen 9539
#define sipName_setShadesPen &sipStrings_QtChart[9539]
#define sipNameNr_setTickCount 9552
#define sipName_setTickCount &sipStrings_QtChart[9552]
#define sipNameNr_setTimestamp 9565
#define sipName_setTimestamp &sipStrings_QtChart[9565]
#define sipNameNr_setTitleFont 9578
#define sipName_setTitleFont &sipStrings_QtChart[9578]
#define sipNameNr_setTitleText 9591
#define sipName_setTitleText &sipStrings_QtChart[9591]
#define sipNameNr_setUseOpenGL 9604
#define sipName_setUseOpenGL &sipStrings_QtChart[9604]
#define sipNameNr_setValuesRow 9617
#define sipName_setValuesRow &sipStrings_QtChart[9617]
#define sipNameNr_shapeChanged 9630
#define sipName_shapeChanged &sipStrings_QtChart[9630]
#define sipNameNr_showToolTips 9643
#define sipName_showToolTips &sipStrings_QtChart[9643]
#define sipNameNr_tickInterval 9656
#define sipName_tickInterval &sipStrings_QtChart[9656]
#define sipNameNr_timestampRow 9669
#define sipName_timestampRow &sipStrings_QtChart[9669]
#define sipNameNr_valueChanged 9682
#define sipName_valueChanged &sipStrings_QtChart[9682]
#define sipNameNr_valuesColumn 9695
#define sipName_valuesColumn &sipStrings_QtChart[9695]
#define sipNameNr_MarkerShape 352
#define sipName_MarkerShape &sipStrings_QtChart[352]
#define sipNameNr_NoAnimation 9708
#define sipName_NoAnimation &sipStrings_QtChart[9708]
#define sipNameNr_QAreaSeries 3141
#define sipName_QAreaSeries &sipStrings_QtChart[3141]
#define sipNameNr_QLineSeries 3163
#define sipName_QLineSeries &sipStrings_QtChart[3163]
#define sipNameNr_QPolarChart 3185
#define sipName_QPolarChart &sipStrings_QtChart[3185]
#define sipNameNr_RubberBands 800
#define sipName_RubberBands &sipStrings_QtChart[800]
#define sipNameNr___getitem__ 9720
#define sipName___getitem__ &sipStrings_QtChart[9720]
#define sipNameNr_actionEvent 9732
#define sipName_actionEvent &sipStrings_QtChart[9732]
#define sipNameNr_baseChanged 9744
#define sipName_baseChanged &sipStrings_QtChart[9744]
#define sipNameNr_borderColor 9756
#define sipName_borderColor &sipStrings_QtChart[9756]
#define sipNameNr_borderWidth 9768
#define sipName_borderWidth &sipStrings_QtChart[9768]
#define sipNameNr_capsVisible 9780
#define sipName_capsVisible &sipStrings_QtChart[9780]
#define sipNameNr_changeEvent 9792
#define sipName_changeEvent &sipStrings_QtChart[9792]
#define sipNameNr_closeColumn 9804
#define sipName_closeColumn &sipStrings_QtChart[9804]
#define sipNameNr_columnCount 9816
#define sipName_columnCount &sipStrings_QtChart[9816]
#define sipNameNr_customEvent 9828
#define sipName_customEvent &sipStrings_QtChart[9828]
#define sipNameNr_eventFilter 9840
#define sipName_eventFilter &sipStrings_QtChart[9840]
#define sipNameNr_firstColumn 9852
#define sipName_firstColumn &sipStrings_QtChart[9852]
#define sipNameNr_firstSetRow 9864
#define sipName_firstSetRow &sipStrings_QtChart[9864]
#define sipNameNr_fontChanged 9876
#define sipName_fontChanged &sipStrings_QtChart[9876]
#define sipNameNr_gridLinePen 9888
#define sipName_gridLinePen &sipStrings_QtChart[9888]
#define sipNameNr_highChanged 9900
#define sipName_highChanged &sipStrings_QtChart[9900]
#define sipNameNr_initPainter 9912
#define sipName_initPainter &sipStrings_QtChart[9912]
#define sipNameNr_labelFormat 9924
#define sipName_labelFormat &sipStrings_QtChart[9924]
#define sipNameNr_labelsAngle 9936
#define sipName_labelsAngle &sipStrings_QtChart[9936]
#define sipNameNr_labelsBrush 9948
#define sipName_labelsBrush &sipStrings_QtChart[9948]
#define sipNameNr_labelsColor 9960
#define sipName_labelsColor &sipStrings_QtChart[9960]
#define sipNameNr_lowerSeries 9972
#define sipName_lowerSeries &sipStrings_QtChart[9972]
#define sipNameNr_markerShape 9984
#define sipName_markerShape &sipStrings_QtChart[9984]
#define sipNameNr_nameChanged 9996
#define sipName_nameChanged &sipStrings_QtChart[9996]
#define sipNameNr_nativeEvent 10008
#define sipName_nativeEvent &sipStrings_QtChart[10008]
#define sipNameNr_openChanged 10020
#define sipName_openChanged &sipStrings_QtChart[10020]
#define sipNameNr_orientation 10032
#define sipName_orientation &sipStrings_QtChart[10032]
#define sipNameNr_paintEngine 10044
#define sipName_paintEngine &sipStrings_QtChart[10044]
#define sipNameNr_pieEndAngle 10056
#define sipName_pieEndAngle &sipStrings_QtChart[10056]
#define sipNameNr_polishEvent 10068
#define sipName_polishEvent &sipStrings_QtChart[10068]
#define sipNameNr_resizeEvent 10080
#define sipName_resizeEvent &sipStrings_QtChart[10080]
#define sipNameNr_setBarWidth 10092
#define sipName_setBarWidth &sipStrings_QtChart[10092]
#define sipNameNr_setBoxWidth 10104
#define sipName_setBoxWidth &sipStrings_QtChart[10104]
#define sipNameNr_setCloseRow 10116
#define sipName_setCloseRow &sipStrings_QtChart[10116]
#define sipNameNr_setExploded 10128
#define sipName_setExploded &sipStrings_QtChart[10128]
#define sipNameNr_setFirstRow 10140
#define sipName_setFirstRow &sipStrings_QtChart[10140]
#define sipNameNr_setGeometry 10152
#define sipName_setGeometry &sipStrings_QtChart[10152]
#define sipNameNr_setHoleSize 10164
#define sipName_setHoleSize &sipStrings_QtChart[10164]
#define sipNameNr_setPlotArea 10176
#define sipName_setPlotArea &sipStrings_QtChart[10176]
#define sipNameNr_setRowCount 10188
#define sipName_setRowCount &sipStrings_QtChart[10188]
#define sipNameNr_setTickType 10200
#define sipName_setTickType &sipStrings_QtChart[10200]
#define sipNameNr_shadesBrush 10212
#define sipName_shadesBrush &sipStrings_QtChart[10212]
#define sipNameNr_shadesColor 10224
#define sipName_shadesColor &sipStrings_QtChart[10224]
#define sipNameNr_tabletEvent 10236
#define sipName_tabletEvent &sipStrings_QtChart[10236]
#define sipNameNr_upperSeries 10248
#define sipName_upperSeries &sipStrings_QtChart[10248]
#define sipNameNr_valuesAdded 10260
#define sipName_valuesAdded &sipStrings_QtChart[10260]
#define sipNameNr_xRowChanged 10272
#define sipName_xRowChanged &sipStrings_QtChart[10272]
#define sipNameNr_yRowChanged 10284
#define sipName_yRowChanged &sipStrings_QtChart[10284]
#define sipNameNr_ChartTheme 1233
#define sipName_ChartTheme &sipStrings_QtChart[1233]
#define sipNameNr_QBarSeries 3666
#define sipName_QBarSeries &sipStrings_QtChart[3666]
#define sipNameNr_QChartView 3687
#define sipName_QChartView &sipStrings_QtChart[3687]
#define sipNameNr_QPieSeries 3708
#define sipName_QPieSeries &sipStrings_QtChart[3708]
#define sipNameNr_QValueAxis 3729
#define sipName_QValueAxis &sipStrings_QtChart[3729]
#define sipNameNr_RubberBand 834
#define sipName_RubberBand &sipStrings_QtChart[834]
#define sipNameNr_SeriesType 239
#define sipName_SeriesType &sipStrings_QtChart[239]
#define sipNameNr_TicksFixed 10296
#define sipName_TicksFixed &sipStrings_QtChart[10296]
#define sipNameNr___invert__ 10307
#define sipName___invert__ &sipStrings_QtChart[10307]
#define sipNameNr___lshift__ 10318
#define sipName___lshift__ &sipStrings_QtChart[10318]
#define sipNameNr_attachAxis 10329
#define sipName_attachAxis &sipStrings_QtChart[10329]
#define sipNameNr_categories 10340
#define sipName_categories &sipStrings_QtChart[10340]
#define sipNameNr_childEvent 10351
#define sipName_childEvent &sipStrings_QtChart[10351]
#define sipNameNr_closeEvent 10362
#define sipName_closeEvent &sipStrings_QtChart[10362]
#define sipNameNr_detachAxis 10373
#define sipName_detachAxis &sipStrings_QtChart[10373]
#define sipNameNr_enterEvent 10384
#define sipName_enterEvent &sipStrings_QtChart[10384]
#define sipNameNr_highColumn 10395
#define sipName_highColumn &sipStrings_QtChart[10395]
#define sipNameNr_isExploded 10406
#define sipName_isExploded &sipStrings_QtChart[10406]
#define sipNameNr_itemChange 10417
#define sipName_itemChange &sipStrings_QtChart[10417]
#define sipNameNr_labelBrush 10428
#define sipName_labelBrush &sipStrings_QtChart[10428]
#define sipNameNr_labelColor 10439
#define sipName_labelColor &sipStrings_QtChart[10439]
#define sipNameNr_labelsFont 10450
#define sipName_labelsFont &sipStrings_QtChart[10450]
#define sipNameNr_lastSetRow 10461
#define sipName_lastSetRow &sipStrings_QtChart[10461]
#define sipNameNr_leaveEvent 10472
#define sipName_leaveEvent &sipStrings_QtChart[10472]
#define sipNameNr_lowChanged 10483
#define sipName_lowChanged &sipStrings_QtChart[10483]
#define sipNameNr_mapToValue 10494
#define sipName_mapToValue &sipStrings_QtChart[10494]
#define sipNameNr_markerSize 10505
#define sipName_markerSize &sipStrings_QtChart[10505]
#define sipNameNr_maxChanged 10516
#define sipName_maxChanged &sipStrings_QtChart[10516]
#define sipNameNr_minChanged 10527
#define sipName_minChanged &sipStrings_QtChart[10527]
#define sipNameNr_opaqueArea 10538
#define sipName_opaqueArea &sipStrings_QtChart[10538]
#define sipNameNr_openColumn 10549
#define sipName_openColumn &sipStrings_QtChart[10549]
#define sipNameNr_paintEvent 10560
#define sipName_paintEvent &sipStrings_QtChart[10560]
#define sipNameNr_penChanged 10021
#define sipName_penChanged &sipStrings_QtChart[10021]
#define sipNameNr_percentage 10571
#define sipName_percentage &sipStrings_QtChart[10571]
#define sipNameNr_pointAdded 10582
#define sipName_pointAdded &sipStrings_QtChart[10582]
#define sipNameNr_removeAxis 10593
#define sipName_removeAxis &sipStrings_QtChart[10593]
#define sipNameNr_rubberBand 10604
#define sipName_rubberBand &sipStrings_QtChart[10604]
#define sipNameNr_sceneEvent 10615
#define sipName_sceneEvent &sipStrings_QtChart[10615]
#define sipNameNr_setHighRow 10626
#define sipName_setHighRow &sipStrings_QtChart[10626]
#define sipNameNr_setLinePen 10637
#define sipName_setLinePen &sipStrings_QtChart[10637]
#define sipNameNr_setMargins 10648
#define sipName_setMargins &sipStrings_QtChart[10648]
#define sipNameNr_setOpacity 10659
#define sipName_setOpacity &sipStrings_QtChart[10659]
#define sipNameNr_setOpenRow 10670
#define sipName_setOpenRow &sipStrings_QtChart[10670]
#define sipNameNr_setPieSize 10681
#define sipName_setPieSize &sipStrings_QtChart[10681]
#define sipNameNr_setReverse 10692
#define sipName_setReverse &sipStrings_QtChart[10692]
#define sipNameNr_setVisible 10703
#define sipName_setVisible &sipStrings_QtChart[10703]
#define sipNameNr_setXColumn 10714
#define sipName_setXColumn &sipStrings_QtChart[10714]
#define sipNameNr_setYColumn 10725
#define sipName_setYColumn &sipStrings_QtChart[10725]
#define sipNameNr_startAngle 10736
#define sipName_startAngle &sipStrings_QtChart[10736]
#define sipNameNr_startValue 10747
#define sipName_startValue &sipStrings_QtChart[10747]
#define sipNameNr_sumChanged 10758
#define sipName_sumChanged &sipStrings_QtChart[10758]
#define sipNameNr_tickAnchor 10769
#define sipName_tickAnchor &sipStrings_QtChart[10769]
#define sipNameNr_timerEvent 10780
#define sipName_timerEvent &sipStrings_QtChart[10780]
#define sipNameNr_titleBrush 10791
#define sipName_titleBrush &sipStrings_QtChart[10791]
#define sipNameNr_wheelEvent 10802
#define sipName_wheelEvent &sipStrings_QtChart[10802]
#define sipNameNr_AxisTypes 389
#define sipName_AxisTypes &sipStrings_QtChart[389]
#define sipNameNr_ChartType 1433
#define sipName_ChartType &sipStrings_QtChart[1433]
#define sipNameNr_QPieSlice 4271
#define sipName_QPieSlice &sipStrings_QtChart[4271]
#define sipNameNr_QXYSeries 4291
#define sipName_QXYSeries &sipStrings_QtChart[4291]
#define sipNameNr___index__ 10813
#define sipName___index__ &sipStrings_QtChart[10813]
#define sipNameNr_addSeries 10823
#define sipName_addSeries &sipStrings_QtChart[10823]
#define sipNameNr_alignment 10833
#define sipName_alignment &sipStrings_QtChart[10833]
#define sipNameNr_angleSpan 10843
#define sipName_angleSpan &sipStrings_QtChart[10843]
#define sipNameNr_bodyWidth 10853
#define sipName_bodyWidth &sipStrings_QtChart[10853]
#define sipNameNr_capsWidth 10863
#define sipName_capsWidth &sipStrings_QtChart[10863]
#define sipNameNr_chartType 10873
#define sipName_chartType &sipStrings_QtChart[10873]
#define sipNameNr_dropEvent 10883
#define sipName_dropEvent &sipStrings_QtChart[10883]
#define sipNameNr_hideEvent 10893
#define sipName_hideEvent &sipStrings_QtChart[10893]
#define sipNameNr_isReverse 10903
#define sipName_isReverse &sipStrings_QtChart[10903]
#define sipNameNr_isVisible 10913
#define sipName_isVisible &sipStrings_QtChart[10913]
#define sipNameNr_labelFont 10923
#define sipName_labelFont &sipStrings_QtChart[10923]
#define sipNameNr_labelsRow 10933
#define sipName_labelsRow &sipStrings_QtChart[10933]
#define sipNameNr_lowColumn 10943
#define sipName_lowColumn &sipStrings_QtChart[10943]
#define sipNameNr_moveEvent 10953
#define sipName_moveEvent &sipStrings_QtChart[10953]
#define sipNameNr_setFormat 10963
#define sipName_setFormat &sipStrings_QtChart[10963]
#define sipNameNr_setLocale 10973
#define sipName_setLocale &sipStrings_QtChart[10973]
#define sipNameNr_setLowRow 10983
#define sipName_setLowRow &sipStrings_QtChart[10983]
#define sipNameNr_setSeries 10993
#define sipName_setSeries &sipStrings_QtChart[10993]
#define sipNameNr_shadesPen 11003
#define sipName_shadesPen &sipStrings_QtChart[11003]
#define sipNameNr_showEvent 11013
#define sipName_showEvent &sipStrings_QtChart[11013]
#define sipNameNr_tickCount 11023
#define sipName_tickCount &sipStrings_QtChart[11023]
#define sipNameNr_timestamp 11033
#define sipName_timestamp &sipStrings_QtChart[11033]
#define sipNameNr_titleFont 11043
#define sipName_titleFont &sipStrings_QtChart[11043]
#define sipNameNr_titleText 11053
#define sipName_titleText &sipStrings_QtChart[11053]
#define sipNameNr_useOpenGL 11063
#define sipName_useOpenGL &sipStrings_QtChart[11063]
#define sipNameNr_valuesRow 11073
#define sipName_valuesRow &sipStrings_QtChart[11073]
#define sipNameNr_zoomReset 11083
#define sipName_zoomReset &sipStrings_QtChart[11083]
#define sipNameNr_AxisType 667
#define sipName_AxisType &sipStrings_QtChart[667]
#define sipNameNr_QtCharts 11093
#define sipName_QtCharts &sipStrings_QtChart[11093]
#define sipNameNr_TickType 1086
#define sipName_TickType &sipStrings_QtChart[1086]
#define sipNameNr___bool__ 11102
#define sipName___bool__ &sipStrings_QtChart[11102]
#define sipNameNr___hash__ 11111
#define sipName___hash__ &sipStrings_QtChart[11111]
#define sipNameNr___iand__ 11120
#define sipName___iand__ &sipStrings_QtChart[11120]
#define sipNameNr___ixor__ 11129
#define sipName___ixor__ &sipStrings_QtChart[11129]
#define sipNameNr_barWidth 11138
#define sipName_barWidth &sipStrings_QtChart[11138]
#define sipNameNr_boxWidth 11147
#define sipName_boxWidth &sipStrings_QtChart[11147]
#define sipNameNr_closeRow 11156
#define sipName_closeRow &sipStrings_QtChart[11156]
#define sipNameNr_contains 11165
#define sipName_contains &sipStrings_QtChart[11165]
#define sipNameNr_editable 11174
#define sipName_editable &sipStrings_QtChart[11174]
#define sipNameNr_endValue 11183
#define sipName_endValue &sipStrings_QtChart[11183]
#define sipNameNr_exploded 11192
#define sipName_exploded &sipStrings_QtChart[11192]
#define sipNameNr_firstRow 11201
#define sipName_firstRow &sipStrings_QtChart[11201]
#define sipNameNr_holeSize 11210
#define sipName_holeSize &sipStrings_QtChart[11210]
#define sipNameNr_isZoomed 11219
#define sipName_isZoomed &sipStrings_QtChart[11219]
#define sipNameNr_plotArea 11228
#define sipName_plotArea &sipStrings_QtChart[11228]
#define sipNameNr_released 11237
#define sipName_released &sipStrings_QtChart[11237]
#define sipNameNr_rowCount 11246
#define sipName_rowCount &sipStrings_QtChart[11246]
#define sipNameNr_selected 11255
#define sipName_selected &sipStrings_QtChart[11255]
#define sipNameNr_setAxisX 11264
#define sipName_setAxisX &sipStrings_QtChart[11264]
#define sipNameNr_setAxisY 11273
#define sipName_setAxisY &sipStrings_QtChart[11273]
#define sipNameNr_setBrush 11282
#define sipName_setBrush &sipStrings_QtChart[11282]
#define sipNameNr_setChart 11291
#define sipName_setChart &sipStrings_QtChart[11291]
#define sipNameNr_setClose 11300
#define sipName_setClose &sipStrings_QtChart[11300]
#define sipNameNr_setColor 11309
#define sipName_setColor &sipStrings_QtChart[11309]
#define sipNameNr_setLabel 11318
#define sipName_setLabel &sipStrings_QtChart[11318]
#define sipNameNr_setModel 11327
#define sipName_setModel &sipStrings_QtChart[11327]
#define sipNameNr_setRange 11336
#define sipName_setRange &sipStrings_QtChart[11336]
#define sipNameNr_setShape 11345
#define sipName_setShape &sipStrings_QtChart[11345]
#define sipNameNr_setTheme 11354
#define sipName_setTheme &sipStrings_QtChart[11354]
#define sipNameNr_setTitle 11363
#define sipName_setTitle &sipStrings_QtChart[11363]
#define sipNameNr_setValue 11372
#define sipName_setValue &sipStrings_QtChart[11372]
#define sipNameNr_sizeHint 11381
#define sipName_sizeHint &sipStrings_QtChart[11381]
#define sipNameNr_tickType 11390
#define sipName_tickType &sipStrings_QtChart[11390]
#define sipNameNr_QBarSet 5543
#define sipName_QBarSet &sipStrings_QtChart[5543]
#define sipNameNr_QBoxSet 5561
#define sipName_QBoxSet &sipStrings_QtChart[5561]
#define sipNameNr_QLegend 5579
#define sipName_QLegend &sipStrings_QtChart[5579]
#define sipNameNr___and__ 11399
#define sipName___and__ &sipStrings_QtChart[11399]
#define sipNameNr___int__ 11407
#define sipName___int__ &sipStrings_QtChart[11407]
#define sipNameNr___ior__ 11415
#define sipName___ior__ &sipStrings_QtChart[11415]
#define sipNameNr___len__ 11423
#define sipName___len__ &sipStrings_QtChart[11423]
#define sipNameNr___xor__ 11431
#define sipName___xor__ &sipStrings_QtChart[11431]
#define sipNameNr_addAxis 11439
#define sipName_addAxis &sipStrings_QtChart[11439]
#define sipNameNr_advance 11447
#define sipName_advance &sipStrings_QtChart[11447]
#define sipNameNr_barSets 11455
#define sipName_barSets &sipStrings_QtChart[11455]
#define sipNameNr_boxSets 11463
#define sipName_boxSets &sipStrings_QtChart[11463]
#define sipNameNr_cleared 11471
#define sipName_cleared &sipStrings_QtChart[11471]
#define sipNameNr_clicked 11479
#define sipName_clicked &sipStrings_QtChart[11479]
#define sipNameNr_devType 11487
#define sipName_devType &sipStrings_QtChart[11487]
#define sipNameNr_enabled 11495
#define sipName_enabled &sipStrings_QtChart[11495]
#define sipNameNr_highRow 11503
#define sipName_highRow &sipStrings_QtChart[11503]
#define sipNameNr_hovered 11511
#define sipName_hovered &sipStrings_QtChart[11511]
#define sipNameNr_isEmpty 11519
#define sipName_isEmpty &sipStrings_QtChart[11519]
#define sipNameNr_linePen 11527
#define sipName_linePen &sipStrings_QtChart[11527]
#define sipNameNr_margins 11535
#define sipName_margins &sipStrings_QtChart[11535]
#define sipNameNr_markers 11543
#define sipName_markers &sipStrings_QtChart[11543]
#define sipNameNr_opacity 11551
#define sipName_opacity &sipStrings_QtChart[11551]
#define sipNameNr_openRow 11559
#define sipName_openRow &sipStrings_QtChart[11559]
#define sipNameNr_pieSize 11567
#define sipName_pieSize &sipStrings_QtChart[11567]
#define sipNameNr_pressed 11575
#define sipName_pressed &sipStrings_QtChart[11575]
#define sipNameNr_removed 11583
#define sipName_removed &sipStrings_QtChart[11583]
#define sipNameNr_replace 11591
#define sipName_replace &sipStrings_QtChart[11591]
#define sipNameNr_reverse 11599
#define sipName_reverse &sipStrings_QtChart[11599]
#define sipNameNr_setBase 11607
#define sipName_setBase &sipStrings_QtChart[11607]
#define sipNameNr_setFont 11615
#define sipName_setFont &sipStrings_QtChart[11615]
#define sipNameNr_setHigh 11623
#define sipName_setHigh &sipStrings_QtChart[11623]
#define sipNameNr_setName 11631
#define sipName_setName &sipStrings_QtChart[11631]
#define sipNameNr_setOpen 11639
#define sipName_setOpen &sipStrings_QtChart[11639]
#define sipNameNr_setXRow 11647
#define sipName_setXRow &sipStrings_QtChart[11647]
#define sipNameNr_setYRow 11655
#define sipName_setYRow &sipStrings_QtChart[11655]
#define sipNameNr_visible 11663
#define sipName_visible &sipStrings_QtChart[11663]
#define sipNameNr_xColumn 11671
#define sipName_xColumn &sipStrings_QtChart[11671]
#define sipNameNr_yColumn 11679
#define sipName_yColumn &sipStrings_QtChart[11679]
#define sipNameNr_zoomOut 11687
#define sipName_zoomOut &sipStrings_QtChart[11687]
#define sipNameNr_Median 11695
#define sipName_Median &sipStrings_QtChart[11695]
#define sipNameNr_QChart 6294
#define sipName_QChart &sipStrings_QtChart[6294]
#define sipNameNr___eq__ 11702
#define sipName___eq__ &sipStrings_QtChart[11702]
#define sipNameNr___ne__ 11709
#define sipName___ne__ &sipStrings_QtChart[11709]
#define sipNameNr___or__ 11716
#define sipName___or__ &sipStrings_QtChart[11716]
#define sipNameNr_append 11723
#define sipName_append &sipStrings_QtChart[11723]
#define sipNameNr_barset 11730
#define sipName_barset &sipStrings_QtChart[11730]
#define sipNameNr_enable 11737
#define sipName_enable &sipStrings_QtChart[11737]
#define sipNameNr_format 11744
#define sipName_format &sipStrings_QtChart[11744]
#define sipNameNr_insert 11751
#define sipName_insert &sipStrings_QtChart[11751]
#define sipNameNr_legend 11758
#define sipName_legend &sipStrings_QtChart[11758]
#define sipNameNr_locale 11765
#define sipName_locale &sipStrings_QtChart[11765]
#define sipNameNr_lowRow 11772
#define sipName_lowRow &sipStrings_QtChart[11772]
#define sipNameNr_metric 11779
#define sipName_metric &sipStrings_QtChart[11779]
#define sipNameNr_parent 11786
#define sipName_parent &sipStrings_QtChart[11786]
#define sipNameNr_points 11793
#define sipName_points &sipStrings_QtChart[11793]
#define sipNameNr_remove 11800
#define sipName_remove &sipStrings_QtChart[11800]
#define sipNameNr_scroll 11807
#define sipName_scroll &sipStrings_QtChart[11807]
#define sipNameNr_series 11814
#define sipName_series &sipStrings_QtChart[11814]
#define sipNameNr_setLow 11821
#define sipName_setLow &sipStrings_QtChart[11821]
#define sipNameNr_setMax 11828
#define sipName_setMax &sipStrings_QtChart[11828]
#define sipNameNr_setMin 11835
#define sipName_setMin &sipStrings_QtChart[11835]
#define sipNameNr_setPen 11842
#define sipName_setPen &sipStrings_QtChart[11842]
#define sipNameNr_slices 11849
#define sipName_slices &sipStrings_QtChart[11849]
#define sipNameNr_widget 11856
#define sipName_widget &sipStrings_QtChart[11856]
#define sipNameNr_zoomIn 11863
#define sipName_zoomIn &sipStrings_QtChart[11863]
#define sipNameNr_added 11870
#define sipName_added &sipStrings_QtChart[11870]
#define sipNameNr_axisX 11876
#define sipName_axisX &sipStrings_QtChart[11876]
#define sipNameNr_axisY 11882
#define sipName_axisY &sipStrings_QtChart[11882]
#define sipNameNr_brush 11888
#define sipName_brush &sipStrings_QtChart[11888]
#define sipNameNr_chart 11894
#define sipName_chart &sipStrings_QtChart[11894]
#define sipNameNr_clear 11900
#define sipName_clear &sipStrings_QtChart[11900]
#define sipNameNr_close 11906
#define sipName_close &sipStrings_QtChart[11906]
#define sipNameNr_color 11912
#define sipName_color &sipStrings_QtChart[11912]
#define sipNameNr_count 11918
#define sipName_count &sipStrings_QtChart[11918]
#define sipNameNr_event 11924
#define sipName_event &sipStrings_QtChart[11924]
#define sipNameNr_flags 11930
#define sipName_flags &sipStrings_QtChart[11930]
#define sipNameNr_label 11936
#define sipName_label &sipStrings_QtChart[11936]
#define sipNameNr_model 11942
#define sipName_model &sipStrings_QtChart[11942]
#define sipNameNr_paint 11948
#define sipName_paint &sipStrings_QtChart[11948]
#define sipNameNr_shape 11954
#define sipName_shape &sipStrings_QtChart[11954]
#define sipNameNr_slice 11960
#define sipName_slice &sipStrings_QtChart[11960]
#define sipNameNr_theme 11966
#define sipName_theme &sipStrings_QtChart[11966]
#define sipNameNr_title 11972
#define sipName_title &sipStrings_QtChart[11972]
#define sipNameNr_value 11978
#define sipName_value &sipStrings_QtChart[11978]
#define sipNameNr_axes 11984
#define sipName_axes &sipStrings_QtChart[11984]
#define sipNameNr_base 11989
#define sipName_base &sipStrings_QtChart[11989]
#define sipNameNr_font 11994
#define sipName_font &sipStrings_QtChart[11994]
#define sipNameNr_hide 11999
#define sipName_hide &sipStrings_QtChart[11999]
#define sipNameNr_high 12004
#define sipName_high &sipStrings_QtChart[12004]
#define sipNameNr_name 12009
#define sipName_name &sipStrings_QtChart[12009]
#define sipNameNr_open 12014
#define sipName_open &sipStrings_QtChart[12014]
#define sipNameNr_sets 12019
#define sipName_sets &sipStrings_QtChart[12019]
#define sipNameNr_show 12024
#define sipName_show &sipStrings_QtChart[12024]
#define sipNameNr_take 12029
#define sipName_take &sipStrings_QtChart[12029]
#define sipNameNr_type 12034
#define sipName_type &sipStrings_QtChart[12034]
#define sipNameNr_xRow 12039
#define sipName_xRow &sipStrings_QtChart[12039]
#define sipNameNr_yRow 12044
#define sipName_yRow &sipStrings_QtChart[12044]
#define sipNameNr_zoom 12049
#define sipName_zoom &sipStrings_QtChart[12049]
#define sipNameNr_low 12054
#define sipName_low &sipStrings_QtChart[12054]
#define sipNameNr_max 12058
#define sipName_max &sipStrings_QtChart[12058]
#define sipNameNr_min 12062
#define sipName_min &sipStrings_QtChart[12062]
#define sipNameNr_pen 11643
#define sipName_pen &sipStrings_QtChart[11643]
#define sipNameNr_sum 12066
#define sipName_sum &sipStrings_QtChart[12066]
#define sipNameNr_at 4115
#define sipName_at &sipStrings_QtChart[4115]

#define sipMalloc                   sipAPI_QtChart->api_malloc
#define sipFree                     sipAPI_QtChart->api_free
#define sipBuildResult              sipAPI_QtChart->api_build_result
#define sipCallMethod               sipAPI_QtChart->api_call_method
#define sipCallProcedureMethod      sipAPI_QtChart->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtChart->api_call_error_handler
#define sipParseResultEx            sipAPI_QtChart->api_parse_result_ex
#define sipParseResult              sipAPI_QtChart->api_parse_result
#define sipParseArgs                sipAPI_QtChart->api_parse_args
#define sipParseKwdArgs             sipAPI_QtChart->api_parse_kwd_args
#define sipParsePair                sipAPI_QtChart->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtChart->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtChart->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtChart->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtChart->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtChart->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtChart->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtChart->api_add_exception
#define sipNoFunction               sipAPI_QtChart->api_no_function
#define sipNoMethod                 sipAPI_QtChart->api_no_method
#define sipAbstractMethod           sipAPI_QtChart->api_abstract_method
#define sipBadClass                 sipAPI_QtChart->api_bad_class
#define sipBadCatcherResult         sipAPI_QtChart->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtChart->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtChart->api_bad_operator_arg
#define sipTrace                    sipAPI_QtChart->api_trace
#define sipTransferBack             sipAPI_QtChart->api_transfer_back
#define sipTransferTo               sipAPI_QtChart->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtChart->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtChart->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtChart->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtChart->api_voidptr_type
#define sipGetPyObject              sipAPI_QtChart->api_get_pyobject
#define sipGetAddress               sipAPI_QtChart->api_get_address
#define sipGetMixinAddress          sipAPI_QtChart->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtChart->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtChart->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtChart->api_call_hook
#define sipEndThread                sipAPI_QtChart->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtChart->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtChart->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtChart->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtChart->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtChart->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtChart->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtChart->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtChart->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtChart->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtChart->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtChart->api_convert_to_bool
#define sipReleaseType              sipAPI_QtChart->api_release_type
#define sipConvertFromType          sipAPI_QtChart->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtChart->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtChart->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtChart->api_convert_from_enum
#define sipGetState                 sipAPI_QtChart->api_get_state
#define sipExportSymbol             sipAPI_QtChart->api_export_symbol
#define sipImportSymbol             sipAPI_QtChart->api_import_symbol
#define sipFindType                 sipAPI_QtChart->api_find_type
#define sipBytes_AsChar             sipAPI_QtChart->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtChart->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtChart->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtChart->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtChart->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtChart->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtChart->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtChart->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtChart->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtChart->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtChart->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtChart->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtChart->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtChart->api_get_reference
#define sipKeepReference            sipAPI_QtChart->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtChart->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtChart->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtChart->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtChart->api_type_scope
#define sipResolveTypedef           sipAPI_QtChart->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtChart->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtChart->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtChart->api_init_mixin
#define sipExportModule             sipAPI_QtChart->api_export_module
#define sipInitModule               sipAPI_QtChart->api_init_module
#define sipGetInterpreter           sipAPI_QtChart->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtChart->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtChart->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtChart->api_py_type_dict
#define sipPyTypeName               sipAPI_QtChart->api_py_type_name
#define sipGetCFunction             sipAPI_QtChart->api_get_c_function
#define sipGetMethod                sipAPI_QtChart->api_get_method
#define sipFromMethod               sipAPI_QtChart->api_from_method
#define sipGetDate                  sipAPI_QtChart->api_get_date
#define sipFromDate                 sipAPI_QtChart->api_from_date
#define sipGetDateTime              sipAPI_QtChart->api_get_datetime
#define sipFromDateTime             sipAPI_QtChart->api_from_datetime
#define sipGetTime                  sipAPI_QtChart->api_get_time
#define sipFromTime                 sipAPI_QtChart->api_from_time
#define sipIsUserType               sipAPI_QtChart->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtChart->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtChart->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtChart->api_unicode_write
#define sipUnicodeData              sipAPI_QtChart->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtChart->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtChart->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtChart->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtChart->api_is_derived_class
#define sipGetUserObject            sipAPI_QtChart->api_get_user_object
#define sipSetUserObject            sipAPI_QtChart->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtChart->api_register_event_handler
#define sipConvertToArray           sipAPI_QtChart->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtChart->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtChart->api_enable_gc
#define sipPrintObject              sipAPI_QtChart->api_print_object
#define sipLong_AsChar              sipAPI_QtChart->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtChart->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtChart->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtChart->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtChart->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtChart->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtChart->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtChart->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtChart->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtChart->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtChart->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtChart->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtChart->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtChart->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtChart->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtChart->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtChart->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtChart->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtChart->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtChart->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtChart->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtChart->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtChart->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtChart->api_connect_rx
#define sipConvertRx                sipAPI_QtChart->api_convert_rx
#define sipDisconnectRx             sipAPI_QtChart->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtChart->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtChart->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtChart->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtChart->api_same_slot
#define sipSaveSlot                 sipAPI_QtChart->api_save_slot
#define sipVisitSlot                sipAPI_QtChart->api_visit_slot
#define sipIsPyMethod               sipAPI_QtChart->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtChart[];


#define sipType_QtCharts_QAbstractAxis sipExportedTypes_QtChart[8]

#define sipType_QtCharts_QAbstractAxis_AxisType sipExportedTypes_QtChart[9]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractAxis;

#define sipType_QtCharts_QAbstractAxis_AxisTypes sipExportedTypes_QtChart[10]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractAxis_AxisTypes;

#define sipType_QtCharts_QAbstractSeries sipExportedTypes_QtChart[13]

#define sipType_QtCharts_QAbstractSeries_SeriesType sipExportedTypes_QtChart[14]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractSeries;

#define sipType_QtCharts_QAbstractBarSeries sipExportedTypes_QtChart[11]

#define sipType_QtCharts_QAbstractBarSeries_LabelsPosition sipExportedTypes_QtChart[12]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAbstractBarSeries;

#define sipType_QtCharts_QLegendMarker sipExportedTypes_QtChart[50]

#define sipType_QtCharts_QLegendMarker_LegendMarkerType sipExportedTypes_QtChart[51]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QLegendMarker;

#define sipType_QtCharts_QAreaLegendMarker sipExportedTypes_QtChart[15]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAreaLegendMarker;

#define sipType_QtCharts_QAreaSeries sipExportedTypes_QtChart[16]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QAreaSeries;

#define sipType_QtCharts_QBarCategoryAxis sipExportedTypes_QtChart[17]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBarCategoryAxis;

#define sipType_QtCharts_QBarLegendMarker sipExportedTypes_QtChart[18]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBarLegendMarker;

#define sipType_QtCharts_QBarSeries sipExportedTypes_QtChart[19]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBarSeries;

#define sipType_QtCharts_QBarSet sipExportedTypes_QtChart[20]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBarSet;

#define sipType_QtCharts_QBoxPlotLegendMarker sipExportedTypes_QtChart[21]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBoxPlotLegendMarker;

#define sipType_QtCharts_QBoxPlotSeries sipExportedTypes_QtChart[22]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBoxPlotSeries;

#define sipType_QtCharts_QBoxSet sipExportedTypes_QtChart[23]

#define sipType_QtCharts_QBoxSet_ValuePositions sipExportedTypes_QtChart[24]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QBoxSet;

#define sipType_QtCharts_QCandlestickLegendMarker sipExportedTypes_QtChart[25]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCandlestickLegendMarker;

#define sipType_QtCharts_QCandlestickModelMapper sipExportedTypes_QtChart[26]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCandlestickModelMapper;

#define sipType_QtCharts_QCandlestickSeries sipExportedTypes_QtChart[27]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCandlestickSeries;

#define sipType_QtCharts_QCandlestickSet sipExportedTypes_QtChart[28]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCandlestickSet;

#define sipType_QtCharts_QValueAxis sipExportedTypes_QtChart[71]

#define sipType_QtCharts_QValueAxis_TickType sipExportedTypes_QtChart[72]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QValueAxis;

#define sipType_QtCharts_QCategoryAxis sipExportedTypes_QtChart[29]

#define sipType_QtCharts_QCategoryAxis_AxisLabelsPosition sipExportedTypes_QtChart[30]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QCategoryAxis;

#define sipType_QtCharts_QChart sipExportedTypes_QtChart[31]

#define sipType_QtCharts_QChart_ChartType sipExportedTypes_QtChart[35]

#define sipType_QtCharts_QChart_AnimationOption sipExportedTypes_QtChart[32]

#define sipType_QtCharts_QChart_ChartTheme sipExportedTypes_QtChart[34]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QChart;

#define sipType_QtCharts_QChart_AnimationOptions sipExportedTypes_QtChart[33]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QChart_AnimationOptions;

#define sipType_QtCharts_QChartView sipExportedTypes_QtChart[36]

#define sipType_QtCharts_QChartView_RubberBand sipExportedTypes_QtChart[37]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QChartView;

#define sipType_QtCharts_QChartView_RubberBands sipExportedTypes_QtChart[38]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QChartView_RubberBands;

#define sipType_QtCharts_QDateTimeAxis sipExportedTypes_QtChart[39]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QDateTimeAxis;

#define sipType_QtCharts_QHBarModelMapper sipExportedTypes_QtChart[40]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHBarModelMapper;

#define sipType_QtCharts_QHBoxPlotModelMapper sipExportedTypes_QtChart[41]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHBoxPlotModelMapper;

#define sipType_QtCharts_QHCandlestickModelMapper sipExportedTypes_QtChart[42]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHCandlestickModelMapper;

#define sipType_QtCharts_QHorizontalBarSeries sipExportedTypes_QtChart[45]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHorizontalBarSeries;

#define sipType_QtCharts_QHorizontalPercentBarSeries sipExportedTypes_QtChart[46]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHorizontalPercentBarSeries;

#define sipType_QtCharts_QHorizontalStackedBarSeries sipExportedTypes_QtChart[47]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHorizontalStackedBarSeries;

#define sipType_QtCharts_QHPieModelMapper sipExportedTypes_QtChart[43]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHPieModelMapper;

#define sipType_QtCharts_QHXYModelMapper sipExportedTypes_QtChart[44]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QHXYModelMapper;

#define sipType_QtCharts_QLegend sipExportedTypes_QtChart[48]

#define sipType_QtCharts_QLegend_MarkerShape sipExportedTypes_QtChart[49]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QLegend;

#define sipType_QtCharts_QXYSeries sipExportedTypes_QtChart[74]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QXYSeries;

#define sipType_QtCharts_QLineSeries sipExportedTypes_QtChart[52]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QLineSeries;

#define sipType_QtCharts_QLogValueAxis sipExportedTypes_QtChart[53]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QLogValueAxis;

#define sipType_QtCharts_QPercentBarSeries sipExportedTypes_QtChart[54]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPercentBarSeries;

#define sipType_QtCharts_QPieLegendMarker sipExportedTypes_QtChart[55]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPieLegendMarker;

#define sipType_QtCharts_QPieSeries sipExportedTypes_QtChart[56]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPieSeries;

#define sipType_QtCharts_QPieSlice sipExportedTypes_QtChart[57]

#define sipType_QtCharts_QPieSlice_LabelPosition sipExportedTypes_QtChart[58]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPieSlice;

#define sipType_QtCharts_QPolarChart sipExportedTypes_QtChart[59]

#define sipType_QtCharts_QPolarChart_PolarOrientation sipExportedTypes_QtChart[60]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPolarChart;

#define sipType_QtCharts_QPolarChart_PolarOrientations sipExportedTypes_QtChart[61]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QPolarChart_PolarOrientations;

#define sipType_QtCharts_QScatterSeries sipExportedTypes_QtChart[62]

#define sipType_QtCharts_QScatterSeries_MarkerShape sipExportedTypes_QtChart[63]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QScatterSeries;

#define sipType_QtCharts_QSplineSeries sipExportedTypes_QtChart[64]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QSplineSeries;

#define sipType_QtCharts_QStackedBarSeries sipExportedTypes_QtChart[65]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QStackedBarSeries;

#define sipType_QtCharts_QVBarModelMapper sipExportedTypes_QtChart[66]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QVBarModelMapper;

#define sipType_QtCharts_QVBoxPlotModelMapper sipExportedTypes_QtChart[67]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QVBoxPlotModelMapper;

#define sipType_QtCharts_QVCandlestickModelMapper sipExportedTypes_QtChart[68]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QVCandlestickModelMapper;

#define sipType_QtCharts_QVPieModelMapper sipExportedTypes_QtChart[69]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QVPieModelMapper;

#define sipType_QtCharts_QVXYModelMapper sipExportedTypes_QtChart[70]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QVXYModelMapper;

#define sipType_QtCharts_QXYLegendMarker sipExportedTypes_QtChart[73]

extern sipClassTypeDef sipTypeDef_QtChart_QtCharts_QXYLegendMarker;

#define sipType_QList_0101QtCharts_QPieSlice sipExportedTypes_QtChart[7]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QPieSlice;

#define sipType_QList_0100QPointF sipExportedTypes_QtChart[0]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0100QPointF;

#define sipType_QList_0101QtCharts_QLegendMarker sipExportedTypes_QtChart[6]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QLegendMarker;

#define sipType_QList_0101QtCharts_QAbstractSeries sipExportedTypes_QtChart[2]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QAbstractSeries;

#define sipType_QList_0101QtCharts_QCandlestickSet sipExportedTypes_QtChart[5]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QCandlestickSet;

#define sipType_QList_0101QtCharts_QBoxSet sipExportedTypes_QtChart[4]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QBoxSet;

#define sipType_QList_0101QtCharts_QBarSet sipExportedTypes_QtChart[3]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QBarSet;

#define sipType_QList_0101QtCharts_QAbstractAxis sipExportedTypes_QtChart[1]

extern sipMappedTypeDef sipTypeDef_QtChart_QList_0101QtCharts_QAbstractAxis;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtChart;
extern sipExportedModuleDef sipModuleAPI_QtChart;
extern sipTypeDef *sipExportedTypes_QtChart[];

#define sipType_Qt_WindowFrameSection sipImportedTypes_QtChart_QtCore[27].it_td

#define sipType_Qt_SizeHint sipImportedTypes_QtChart_QtCore[25].it_td

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtChart_QtCore[22].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtChart_QtCore[21].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtChart_QtCore[23].it_td

#define sipType_Qt_Orientations sipImportedTypes_QtChart_QtCore[24].it_td

#define sipType_Qt_Alignment sipImportedTypes_QtChart_QtCore[20].it_td

#define sipType_Qt_WindowFlags sipImportedTypes_QtChart_QtCore[26].it_td

#define sipType_QObject sipImportedTypes_QtChart_QtCore[10].it_td

#define sipType_QAbstractItemModel sipImportedTypes_QtChart_QtCore[0].it_td

#define sipType_QByteArray sipImportedTypes_QtChart_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtChart_QtCore[5].it_td

#define sipType_QTimerEvent sipImportedTypes_QtChart_QtCore[17].it_td

#define sipType_QChildEvent sipImportedTypes_QtChart_QtCore[2].it_td

#define sipType_QDateTime sipImportedTypes_QtChart_QtCore[3].it_td

#define sipType_QEasingCurve sipImportedTypes_QtChart_QtCore[4].it_td

#define sipType_QLocale sipImportedTypes_QtChart_QtCore[7].it_td

#define sipType_QMargins sipImportedTypes_QtChart_QtCore[8].it_td

#define sipType_QMetaMethod sipImportedTypes_QtChart_QtCore[9].it_td

#define sipType_QPointF sipImportedTypes_QtChart_QtCore[11].it_td

#define sipType_QRectF sipImportedTypes_QtChart_QtCore[12].it_td

#define sipType_QSize sipImportedTypes_QtChart_QtCore[13].it_td

#define sipType_QSizeF sipImportedTypes_QtChart_QtCore[14].it_td

#define sipType_QVariant sipImportedTypes_QtChart_QtCore[18].it_td

#define sipType_QVector_0100QPointF sipImportedTypes_QtChart_QtCore[19].it_td

#define sipType_QStringList sipImportedTypes_QtChart_QtCore[16].it_td

#define sipType_QList_2400 sipImportedTypes_QtChart_QtCore[6].it_td

#define sipType_QString sipImportedTypes_QtChart_QtCore[15].it_td
extern sipImportedTypeDef sipImportedTypes_QtChart_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtChart_QtCore[];

#define sipType_QPaintDevice sipImportedTypes_QtChart_QtGui[16].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtChart_QtGui[17].it_td

#define sipType_QColor sipImportedTypes_QtChart_QtGui[3].it_td

#define sipType_QBrush sipImportedTypes_QtChart_QtGui[1].it_td

#define sipType_QMouseEvent sipImportedTypes_QtChart_QtGui[14].it_td

#define sipType_QWheelEvent sipImportedTypes_QtChart_QtGui[26].it_td

#define sipType_QTabletEvent sipImportedTypes_QtChart_QtGui[25].it_td

#define sipType_QKeyEvent sipImportedTypes_QtChart_QtGui[13].it_td

#define sipType_QFocusEvent sipImportedTypes_QtChart_QtGui[9].it_td

#define sipType_QPaintEvent sipImportedTypes_QtChart_QtGui[19].it_td

#define sipType_QMoveEvent sipImportedTypes_QtChart_QtGui[15].it_td

#define sipType_QResizeEvent sipImportedTypes_QtChart_QtGui[23].it_td

#define sipType_QCloseEvent sipImportedTypes_QtChart_QtGui[2].it_td

#define sipType_QShowEvent sipImportedTypes_QtChart_QtGui[24].it_td

#define sipType_QHideEvent sipImportedTypes_QtChart_QtGui[11].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtChart_QtGui[4].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtChart_QtGui[12].it_td

#define sipType_QDropEvent sipImportedTypes_QtChart_QtGui[8].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtChart_QtGui[7].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtChart_QtGui[5].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtChart_QtGui[6].it_td

#define sipType_QActionEvent sipImportedTypes_QtChart_QtGui[0].it_td

#define sipType_QFont sipImportedTypes_QtChart_QtGui[10].it_td

#define sipType_QPainter sipImportedTypes_QtChart_QtGui[20].it_td

#define sipType_QPaintEngine sipImportedTypes_QtChart_QtGui[18].it_td

#define sipType_QPainterPath sipImportedTypes_QtChart_QtGui[21].it_td

#define sipType_QPen sipImportedTypes_QtChart_QtGui[22].it_td
extern sipImportedTypeDef sipImportedTypes_QtChart_QtGui[];

#define sipType_QWidget sipImportedTypes_QtChart_QtWidgets[17].it_td

#define sipType_QFrame sipImportedTypes_QtChart_QtWidgets[1].it_td

#define sipType_QAbstractScrollArea sipImportedTypes_QtChart_QtWidgets[0].it_td

#define sipType_QGraphicsLayoutItem sipImportedTypes_QtChart_QtWidgets[4].it_td

#define sipType_QGraphicsItem sipImportedTypes_QtChart_QtWidgets[2].it_td

#define sipType_QGraphicsItem_GraphicsItemChange sipImportedTypes_QtChart_QtWidgets[3].it_td

#define sipType_QGraphicsObject sipImportedTypes_QtChart_QtWidgets[5].it_td

#define sipType_QGraphicsWidget sipImportedTypes_QtChart_QtWidgets[14].it_td

#define sipType_QGraphicsSceneMouseEvent sipImportedTypes_QtChart_QtWidgets[9].it_td

#define sipType_QGraphicsSceneWheelEvent sipImportedTypes_QtChart_QtWidgets[12].it_td

#define sipType_QGraphicsSceneContextMenuEvent sipImportedTypes_QtChart_QtWidgets[6].it_td

#define sipType_QGraphicsSceneHoverEvent sipImportedTypes_QtChart_QtWidgets[8].it_td

#define sipType_QGraphicsSceneDragDropEvent sipImportedTypes_QtChart_QtWidgets[7].it_td

#define sipType_QGraphicsSceneResizeEvent sipImportedTypes_QtChart_QtWidgets[11].it_td

#define sipType_QGraphicsSceneMoveEvent sipImportedTypes_QtChart_QtWidgets[10].it_td

#define sipType_QGraphicsView sipImportedTypes_QtChart_QtWidgets[13].it_td

#define sipType_QStyleOption sipImportedTypes_QtChart_QtWidgets[15].it_td

#define sipType_QStyleOptionGraphicsItem sipImportedTypes_QtChart_QtWidgets[16].it_td
extern sipImportedTypeDef sipImportedTypes_QtChart_QtWidgets[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtChart_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtChart_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtChart_qt_metacast;

#endif
